;+
; NAME:
;	CHECK_UTC
;
; PURPOSE:
;	Checks the UTC time for reasonableness.
;   
;
; CATEGORY:
;	Support File. 
;
; CALLING SEQUENCE:
;	s=CHECK_UTC(utc)
;
; INPUTS:
;	utc           UTC time string, format = yyyy-doyThh:mm:ss.msc
;
; OUTPUTS:
;   RETURNS 0 for ok, -1 for error
;           
; KEYWORD PARAMETERS:
;
;                       Copyright (C) 2011
; The Johns Hopkins University Applied Physics Laboratory (JHU/APL)
;                       All rights reserved
;
; This material may be used, modified or reproduced by or for the
; U.S. Government pursuant to the license rights granted under
; the clauses at DFARS 252.227-7013/7014.
;
; CREATION:
;       11 May 2011, M.B. Kusterer 
;
; MODIFICATION HISTORY: 
;-
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
PRO TEST_CU

	utc = '1999-365T11:12:14.9999'
	print,utc
	print,CHECK_UTC(utc)

RETURN
END

FUNCTION CHECK_UTC, utcs

    FOR n=0l,N_ELEMENTS(utcs)-1 DO BEGIN
        utc = utcs[n]
	    IF STRMATCH(STRMID(utc,4,1),'-') NE 1 THEN BEGIN
		    PRINT,'CHECK_UTC: Failure in date format'
		    PRINT,'Please use yyyy-doyThh:mm:ss.msc'
		    RETURN,-1
	    ENDIF
	    IF STRMATCH(STRMID(utc,8,1),'T') NE 1 THEN BEGIN
		    PRINT,'CHECK_UTC: Failure in date format'
		    PRINT,'Please use yyyy-doyThh:mm:ss.msc'
		    RETURN,-1
	    ENDIF
	    IF STRLEN(utc) GE 12 THEN $
	    IF STRMATCH(STRMID(utc,11,1),':') NE 1 THEN BEGIN
		    PRINT,'CHECK_UTC: Failure in date format'
		    PRINT,'Please use yyyy-doyThh:mm:ss.msc'
		    RETURN,-1
	    ENDIF
	    IF STRLEN(utc) GE 15 THEN $
	    IF STRMATCH(STRMID(utc,14,1),':') NE 1 THEN BEGIN
		    PRINT,'CHECK_UTC: Failure in date format'
		    PRINT,'Please use yyyy-doyThh:mm:ss.msc'
		    RETURN,-1
	    ENDIF
	    IF STRLEN(utc) GE 18 THEN $
	    IF STRMATCH(STRMID(utc,17,1),'.') NE 1 THEN BEGIN
		    PRINT,'CHECK_UTC: Failure in date format'
		    PRINT,'Please use yyyy-doyThh:mm:ss.msc'
		    RETURN,-1
	    ENDIF

	    TIMESTR2NUM, utc, year, doy, hours, mins, secs, msecs
	    IF year LT 1997 OR year GT 2018 THEN BEGIN
		    PRINT,'CHECK_UTC: Failure in year field ',year
		    RETURN,-1
	    ENDIF

	    lastdoy = YMD2DN(year,12,31)
	    IF doy LT 1 OR doy GT lastdoy THEN BEGIN
		    PRINT,'CHECK_UTC: Failure in day of year field ',doy
		    RETURN,-1
	    ENDIF
	    IF hours LT 0 OR hours GT 23 THEN BEGIN
		    PRINT,'CHECK_UTC: Failure in hours field ',hours
		    RETURN,-1
	    ENDIF
	    IF mins LT 0 OR mins GT 59 THEN BEGIN
		    PRINT,'CHECK_UTC: Failure in minutes field ',mins
		    RETURN,-1
	    ENDIF
	    IF secs LT 0 OR secs GT 59 THEN BEGIN
		    PRINT,'CHECK_UTC: Failure in seconds field ',secs
		    RETURN,-1
	    ENDIF
	    IF msecs LT 0 OR msecs GT 999 THEN BEGIN
		    PRINT,'CHECK_UTC: Failure in milliseconds field ',msecs
		    RETURN,-1
	    ENDIF
    ENDFOR
RETURN,0
END
