;+
; NAME:
;	COMPILE_ALL
;
; PURPOSE:
;	Compile all code associated with an application. Finds any code in directories called
;       by CALL_PROCEDURE, CALL_FUNCTION and compiles them also.
;   
; NOTE: 
;
; CATEGORY:
;	Plotting Structure File. 
;
; CALLING SEQUENCE:
;	COMPILE_ALL, idlprogram
;
; INPUTS:
;   idlprogram Name of application
;
; KEYWORD PARAMETERS:
;
;
;                       Copyright (C) 2009
; The Johns Hopkins University Applied Physics Laboratory (JHU/APL)
;                       All rights reserved
;
; This material may be used, modified or reproduced by or for the
; U.S. Government pursuant to the license rights granted under
; the clauses at DFARS 252.227-7013/7014.
;
; CREATION:
;       22 Sep 2009, M.B. Kusterer 
;
; MODIFICATION HISTORY: 
;-
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
PRO TEST_COMPILE_ALL

	COMPILE_ALL,'mimivm',skip_routines=['I','ANDREAS_PUT_IN_SC_LOCATE','CMAP_FRAME_SELECTION',$
               'GET_CHEMS_LEMMS_CALIB','IMAGE_MENU2','MAR_SCALEMENU','HELP_MENU',$
               'PLOT_DATA_SIZES','PRIORITY','PUT_IN_SC_LOCATE','PUT_IN_SC_SUNNEP',$
               'PUT_IN_SC_VIEW','DECOM_IDLSTART_VM','NEW_HEADER','OLD_WORKING_SPICE_MOSAIC',$
			   'RUN_BATCH','RUN_MAKEJPL','RUN_MAKENOISE','RUN_MIMI_IDL','RUN_MIMI_MENU',$
			   'RUN_NOCKERNELS','RUN_WRITESASF','MIMIVM','INIT_KERNEL_INFO','R_CASSINI_MIMI_CHEMS',$
			   'R_CASSINI_MIMI_LEMMS','R_CASSINI_MIMI_INCA','CONVERT_TIME','HENATIME2STR',$
			   'COMPILE_ALL','IEBDB_MENU','MAKE_VM','PLOT_XINCA_SQUARE2'],$
			   SKIP_DIR=[GETENV('MIMI_IDL_DIR')+PATH_SEP()+'idl/test',$
			   GETENV('MIMI_IDL_DIR')+PATH_SEP()+'idl/xinca/oldxinca']

RETURN
END

PRO COMPILE_ALL, idlprogram, UPONE=UPONE, CODEDIR=CODEDIR,$
				SKIP_ROUTINES=SKIP_ROUTINES, SKIP_DIR=SKIP_DIR



;find where code is
iamat = FILE_WHICH(idlprogram+'.pro')

IF STRMATCH(iamat,'') EQ 1 THEN BEGIN
    PRINT,'Failure to locate idlprogram '+idlprogram+'.pro'
    PRINT,'Exiting'
    RETURN
ENDIF


IF N_ELEMENTS(SKIP_DIR) GT 0 THEN BEGIN
	FOR n=0,N_ELEMENTS(SKIP_DIR)-1 DO BEGIN
		files = STRUPCASE(FILE_BASENAME(FILE_SEARCH(SKIP_DIR[n],'*.pro',COUNT=nfiles),'.pro'))
		IF nfiles GT 0 THEN BEGIN
			SKIP_ROUTINES = (N_ELEMENTS(SKIP_ROUTINES) GT 0) ? [SKIP_ROUTINES,files] : [files]
		ENDIF
	ENDFOR
ENDIF

IF N_ELEMENTS(SKIP_ROUTINES) GT 0 THEN PRINT,'Skipping the following routines ',SKIP_ROUTINES
	
IF N_ELEMENTS(SKIP_ROUTINES) GT 0 THEN BEGIN
    RESOLVE_ALL,RESOLVE_EITHER=idlprogram,/CONTINUE_ON_ERROR,$
        UNRESOLVED=unresolved,SKIP_ROUTINES=SKIP_ROUTINES
ENDIF ELSE BEGIN
    RESOLVE_ALL,RESOLVE_EITHER=idlprogram,/CONTINUE_ON_ERROR,$
        UNRESOLVED=unresolved
ENDELSE
    
IF N_ELEMENTS(unresolved) GT 0 THEN BEGIN
    PRINT,'Unresolved routines'
    print,unresolved
ENDIF

codedir = FILE_DIRNAME(iamat)

;go back up one directory
IF KEYWORD_SET(UPONE) THEN BEGIN
    codedir = STRMID(codedir,0,STRPOS(codedir,PATH_SEP(),/reverse_search))
ENDIF

dirs = FILE_SEARCH(codedir,/TEST_DIRECTORY,COUNT=ndirs)

files = FILE_SEARCH(codedir,'*.pro',COUNT=nfiles)

FOR n=0,nfiles-1 DO BEGIN
    fl = FILE_BASENAME(files[n],'.pro')
    
    ;skip skip routines
    at = -1
    IF N_ELEMENTS(skip_routines) GT 0 THEN BEGIN
        pos = STRMATCH(skip_routines,fl,/FOLD_CASE)
        at = WHERE(pos EQ 1)
    ENDIF
    
    ;skip *_h.pro for martha's header files
    IF at[0] EQ -1 AND STRPOS(fl+'.pro','_h.pro') EQ -1  AND STRPOS(fl,'idlstartup') EQ -1 THEN BEGIN
        print,'compiling '+files[n]
        
        RESOLVE_ROUTINE,fl,/EITHER,/COMPILE_FULL_FILE
        ;IF N_ELEMENTS(unresolved) GT 0 THEN BEGIN
            ;PRINT,'Unresolved routines'
            ;print,unresolved
        ;ENDIF
    ENDIF
ENDFOR

FOR d=0,ndirs-1 DO BEGIN
    files = FILE_SEARCH(dirs[d],'*.pro',COUNT=nfiles)

    FOR n=0,nfiles-1 DO BEGIN
        fl = FILE_BASENAME(files[n],'.pro')
        
        ;skip skip routines
        at = -1
        IF N_ELEMENTS(skip_routines) GT 0 THEN BEGIN
            pos = STRMATCH(skip_routines,fl,/FOLD_CASE)
            at = WHERE(pos EQ 1)
        ENDIF
        
            ;skip *_h.pro for martha's header files
        IF at[0] EQ -1 AND STRPOS(fl+'.pro','_h.pro') EQ -1 AND STRPOS(fl,'idlstartup') EQ -1 THEN BEGIN
            print,'compiling '+files[n]
            RESOLVE_ROUTINE,fl,/EITHER,/COMPILE_FULL_FILE
        ENDIF
    ENDFOR
    
ENDFOR


RETURN
END
