;+
; NAME:
;	GET_DELTA_AT
;
; PURPOSE:
;	REturn the difference in seconds between TAI and UTC (delta_at)
;        from leap second kernel that matches the UTC or TAI
;   
;
; CATEGORY:
;	Plotting Structure File. 
;
; CALLING SEQUENCE:
;	delta_at = GET_DELTA_AT(utc)
;
; INPUTS:
;   utc     String UTC, yyyy-doyThh:mm:ss.msc
;
; OUTPUTS:
;	delta_at    Matching difference in seconds between TAI and UTC
;
;  
; REQUIRES:
;   Uses the leap second common block, assumes setup was run before use
;
;   The leap second file is obtained from "ftp://naif.jpl.nasa.gov/pub/naif/CASSINI/kernels/lsk/" 
;   and the user should check in January and August of each year to see if any leap seconds have 
;   been added.
;        
;
; KEYWORD PARAMETERS:
;
;                       Copyright (C) 2011
; The Johns Hopkins University Applied Physics Laboratory (JHU/APL)
;                       All rights reserved
;
; This material may be used, modified or reproduced by or for the
; U.S. Government pursuant to the license rights granted under
; the clauses at DFARS 252.227-7013/7014.
;
; CREATION:
;       23 May 2011, M.B. Kusterer 
;
; MODIFICATION HISTORY: 
;-
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

PRO TEST_GDA
    
    
    utc = '2005-365T23:59:00.000'
    s=spice_utc2et(utc,et)
    ;print,utc,GET_DELTA_AT(utc),format='(A23,F23.8)'
    tai = UTC2TAI(utc)
    print,utc,GET_DELTA_AT(utc, USETAI=tai),format='(A23,F23.8)'
    
    utc = '2006-001T00:00:00.000'
    s=spice_utc2et(utc,et)
    ;print,utc,GET_DELTA_AT(utc),format='(A23,F23.8)'
    tai = UTC2TAI(utc)
    print,utc,GET_DELTA_AT(utc,  USETAI=tai),format='(A23,F23.8)'

RETURN
END

FUNCTION GET_DELTA_AT, utc,  USETAI=USETAI


COMMON LEAP, ls

    ;figure out which number of leap seconds matches the UTC
    ;convert UTC to julian seconds
    IF N_ELEMENTS(USETAI) EQ 0 THEN BEGIN
        jsecs = UTC2JSECS(utc)
        delta_at_diff = REFORM(ls[0].delta_at[*].diff)
        delta_at_jsecs = REFORM(ls[0].delta_at[*].jsecs)

        diff = delta_at_jsecs - jsecs[0] 
        at = WHERE(diff GT 0)
        IF at[0] EQ -1 THEN use=N_ELEMENTS(delta_at_diff)-1 $
        ELSE IF at[0] GT 0 THEN use=at[0]-1 $
        ELSE use=0
    ;figure out which number of leap seconds matches the TAI
    ENDIF ELSE BEGIN
        delta_at_diff = REFORM(ls[0].delta_at[*].diff)
        delta_at_tai = REFORM(ls[0].delta_at[*].tai)
    
        diff = delta_at_tai - USETAI[0] 
        at = WHERE(diff GT 0)
        IF at[0] EQ -1 THEN use=N_ELEMENTS(delta_at_diff)-1 $
        ELSE IF at[0] GT 0 THEN use=at[0]-1 $
        ELSE use=0
    ENDELSE
    
RETURN,delta_at_diff[use]
END
