;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;+
; NAME:
;	INIT_STRINGS
;
; PURPOSE:
;	Create a string array and initialize each element to a value  len long. It
;   makes sure that the value initialized character pointer points to a different place for 
;   each element. This is necesary for use when string arrays are passed to load in C or C++.
;
; CATEGORY:
;	Initialization routine
;
; CALLING SEQUENCE:
;	new_strarr = INIT_STRINGS(numarr,len)
;
; INPUTS:
;       Numarr  -    long Number of strings desired in array
;       Len     -   Length to initialize for each string in the array
;
; KEYWORD PARAMETERS:
;
; OUTPUTS:
;	RETURNS string array intialized to integers 0 - len string length.
;
; COMMON BLOCKS:
;	None.
;
;                       Copyright (C) 2010
; The Johns Hopkins University Applied Physics Laboratory (JHU/APL)
;                       All rights reserved
;
; This material may be used, modified or reproduced by or for the
; U.S. Government pursuant to the license rights granted under
; the clauses at DFARS 252.227-7013/7014.
;
;
; CREATION:
;       22 Mar 1999, M.B. Kusterer 
;
; MODIFICATION HISTORY:
;-
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
FUNCTION INIT_STRINGS,numarr,len

new_array = STRARR(numarr)
n=0L

; loop through and create a new string value temp which never points to the same place.
; load the new string array elements with the temporary value, integers.
FOR n=0L,numarr-1 DO BEGIN
    temp = strcompress(string(bindgen(len),/print),/remove_all)
    IF N_ELEMENTS(temp) GT 1 THEN BEGIN
        FOR i=1,N_ELEMENTS(temp)-1 DO temp[0] = temp[0]+temp[i]
    ENDIF
    new_array[n] = temp[0]
    temp = 0
ENDFOR

RETURN,new_array

END
