;+
; NAME:
;	NUM2STR
;
; PURPOSE:
;	Program to convert numbers to strings for printing
;
; CATEGORY:
;	Plotting Structure File. 
;
; CALLING SEQUENCE:
;	NUM2STR,mynum
;
; INPUTS:
;	mynum	Input number
;	
; KEYWORD PARAMETERS:
;	SLONG	Optional iwidth.width if greater than 1, else if 1 just casts to long
;	TOP		Return the number < Top
;	BOTTOM	Return the number > Bottom
;
;
;                       Copyright (C) 2010
; The Johns Hopkins University Applied Physics Laboratory (JHU/APL)
;                       All rights reserved
;
; This material may be used, modified or reproduced by or for the
; U.S. Government pursuant to the license rights granted under
; the clauses at DFARS 252.227-7013/7014.
;
; CREATION:
;       29 Jan 2009, M.B. Kusterer 
;
; MODIFICATION HISTORY: 
;-
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
FUNCTION NUM2STR, mynum,  SLONG=SLONG, TOP=TOP, BOTTOM=BOTTOM, DBLFMT=DBLFMT

IF N_ELEMENTS(TOP) GT 0 THEN BEGIN
    num = MIN([TOP,mynum])
ENDIF ELSE IF N_ELEMENTS(BOTTOM) GT 0 THEN BEGIN
    num = MAX([BOTTOM,mynum])
ENDIF ELSE BEGIN
    num = mynum
ENDELSE

IF N_ELEMENTS(SLONG) GT 0 THEN BEGIN
    IF SLONG GT 1 THEN BEGIN
        lstr = STRCOMPRESS(STRING(SLONG),/REMOVE_ALL)
        str = STRCOMPRESS(STRING(LONG(num),FORMAT='(i'+lstr+'.'+lstr+')'),/REMOVE_ALL)
    ENDIF ELSE BEGIN
        str = STRCOMPRESS(STRING(LONG(num)),/REMOVE_ALL)
    ENDELSE
ENDIF ELSE IF N_ELEMENTS(DBLFMT) EQ 2 THEN BEGIN
    str = STRCOMPRESS(STRING(num,FORMAT='(D'+NUM2STR(DBLFMT[0])+'.'+NUM2STR(DBLFMT[1])+')'),/REMOVE_ALL)
ENDIF ELSE BEGIN
    str = STRCOMPRESS(STRING(num),/REMOVE_ALL)
ENDELSE

RETURN,str

END
