;+
; NAME:
;	NUM2TIMESTR
;
; PURPOSE:
;	Convert year, day of year, hours, minutes and seconds to string time format
;   
; NOTE: 
;
; CATEGORY:
;	Plotting Structure File. 
;
; CALLING SEQUENCE:
;	strtime=NUM2TIMESTR(year, doy, hours, mins, secs )
;
; INPUTS:
;   year     integer 4 digit integer year, can be array, must be the same size as all other inputs
;   doy      integer day of year 1-365 or 366 on leap year, can be array, must be the same size as all other inputs
;   hours    integer hours 0-23, can be array, must be the same size as all other inputs, not required
;   mins     integer minutes 0-59, can be array, must be the same size as all other inputs, not required
;   secs     integer seconds 0-59, can be array, must be the same size as all other inputs, not required
;   msecs    integer milliseconds 0-999, can be array, must be the same size as all other inputs, not required
;
;
; OUTPUTS:
;	RETURNS strtime	String or String array of form yyyy-doyThh:mm:ss
;
;
; KEYWORD PARAMETERS:
;
;                       Copyright (C) 2011
; The Johns Hopkins University Applied Physics Laboratory (JHU/APL)
;                       All rights reserved
;
; This material may be used, modified or reproduced by or for the
; U.S. Government pursuant to the license rights granted under
; the clauses at DFARS 252.227-7013/7014.
;
; CREATION:
;       07 Apr 2011, M.B. Kusterer 
;
; MODIFICATION HISTORY: 
;-
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
FUNCTION NUM2TIMESTR, year, doy, hours, mins, secs, msecs

	num = N_ELEMENTS(year)
	IF N_ELEMENTS(hours) EQ 0 THEN hours=LONARR(num)
	IF N_ELEMENTS(mins) EQ 0 THEN mins=LONARR(num)
	IF N_ELEMENTS(secs) EQ 0 THEN secs=LONARR(num)
	IF N_ELEMENTS(msecs) EQ 0 THEN msecs=LONARR(num)
	timestr = STRARR(num)
	FOR n=0,num-1 DO BEGIN
    	timestr[n] = NUM2STR(year[n])+'-'+NUM2STR(doy[n],SLONG=3)+$
			'T'+NUM2STR(hours[n],SLONG=2)+':'+$
                NUM2STR(mins[n],SLONG=2)+':'+NUM2STR(secs[n],SLONG=2)+$
				'.'+NUM2STR(msecs[n],SLONG=3)
	ENDFOR
	
RETURN, timestr
END
