;+
; NAME:
;	PDS_GET_LISTOFCHANS
;
; PURPOSE:
;	Uses flag to set the filename containing the text column labels for the data types
;   
; NOTE:
;	This routine depends on the environmental variable IDL_DIR being set to the 
;	directory of the MIMI IDL files. This is done in
;	the setup.pro routine. The user should edit the setup file to point to their paths.
;
;
; CATEGORY:
;	Subroutine
;
; CALLING SEQUENCE:
;	channellist = GET_LISTOFCHANS(path,sensortype, datatype)
;
; INPUTS:
;   path - string path to data type labels files
;   sensortype - string sensor type
;   datatype - string data type
;   
; KEYWORD PARAMETERS:
;   none
;
; OUTPUTS:  
;   REturns channellist, a string array of data type channels
; COMMON BLOCKS:
;	None. 


;                       Copyright (C) 2011
; The Johns Hopkins University Applied Physics Laboratory (JHU/APL)
;                       All rights reserved
;
; This material may be used, modified or reproduced by or FOR the
; U.S. Government pursuant to the license rights granted under
; the clauses at DFARS 252.227-7013/7014.
;
;
; CREATION:
;       17 Mar 1999, M.B. Kusterer 
;
; MODIFICATION HISTORY:
;       8 Sept 1999, M.B.Kusterer   Added code to set LEMMSACC_FILENAME to one of 
;               two files based on time for change in priority channels.
; 5 Oct 1999    	M.B.Kusterer    Added code to work with hskp subcom,ana/dig, command
;       17 Dec 1999, M.B.Kusterer   Removed code to set LEMMSACC_FILENAME to one of 
;               two files based on time for change in priority channels.
;      17 May 2000, M.B.Kusterer Added code to work with new auxiliary and mag files. 
;      26 Oct 2007, M.B.Kusterer Added chems flux file. 
;      22 July 2008, M.B.Kusterer Removed execute. 
;      02 June 2011, M.B.Kusterer Added PDS_ to name, change spice_et2utc,spice_utc2et to non-spice
;       and changed path from DECOM_CONFIG to IDL_DIR. 
;- 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
FUNCTION PDS_GET_LISTOFCHANS, et, sensortype, datatype

    path = GETENV('IDL_DIR')

    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ; Set up the environmental variables based on desired time
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    result = PDS_SET_LABEL_ENVVAR(et,$
            DECOM_SWVER_FILE,SCIRECHDR_FILENAME,DATAHDR_FILENAME,$
            EXTRAHDR_FILENAME,LEMMSACC_FILENAME,LEMMSPHA_FILENAME,INCAACC_FILENAME,INCAPHA_FILENAME,$
            INCARAW_FILENAME,INCAIMAGE_FILENAME, MIMI_RF_FILE,CHEMSACC_FILENAME,CHEMSPHA_FILENAME,$
            CHEMSRATE_FILENAME,CHEMSRAW_FILENAME,AUX_FILENAME,HSKPANALOGDIG_FILENAME,$
            HSKPSUBCOM_FILENAME,HSKPCMD_FILENAME,MIMI_COMMANDTEXT_FILENAME,$
            MAG_FILENAME,MROHDR_FILENAME,MRODATA_FILENAME,SFDU_FILENAME,CHEMSRATEFLUX_FILENAME)

    CASE sensortype OF 
    'LEMMS' : BEGIN
        CASE datatype OF 
        'Accumulator Rates' : OPENR,unit,path+LEMMSACC_FILENAME,/GET_LUN
        'PHA Data' : OPENR,unit,path+LEMMSPHA_FILENAME,/GET_LUN
        'Auxiliary' : OPENR,unit,path+AUX_FILENAME,/GET_LUN
        'Mag' : OPENR,unit,path+MAG_FILENAME,/GET_LUN
		ELSE : PRINT,'Failure to match datatype '+datatype
        ENDCASE   
    END
    'CHEMS' : BEGIN
        CASE datatype OF 
        'Basic & Science' : OPENR,unit,path+CHEMSRATE_FILENAME,/GET_LUN
        'Accumulator Rates' : OPENR,unit,path+CHEMSACC_FILENAME,/GET_LUN
        'PHA Events' : OPENR,unit,path+CHEMSPHA_FILENAME,/GET_LUN
        'Raw Data' : OPENR,unit,path+CHEMSRAW_FILENAME,/GET_LUN
        'Auxiliary' : OPENR,unit,path+AUX_FILENAME,/GET_LUN
        'Mag' : OPENR,unit,path+MAG_FILENAME,/GET_LUN
        'Flux' : OPENR,unit,path+CHEMSRATEFLUX_FILENAME,/GET_LUN
		ELSE : PRINT,'Failure to match datatype '+datatype
        ENDCASE   
    END
    'INCA' : BEGIN
        CASE datatype OF 
        'Raw & PHA Events' : OPENR,unit,path+INCARAW_FILENAME,/GET_LUN
        'Accumulator Rates' : OPENR,unit,path+INCAACC_FILENAME,/GET_LUN
        'PHA Events' : OPENR,unit,path+INCAPHA_FILENAME,/GET_LUN
        'Auxiliary' : OPENR,unit,path+AUX_FILENAME,/GET_LUN
        'Mag' : OPENR,unit,path+MAG_FILENAME,/GET_LUN
		ELSE : PRINT,'Failure to match datatype '+datatype
        ENDCASE   
    END
    'INCA Images' : BEGIn
        OPENR,unit,path+INCAIMAGE_FILENAME,/GET_LUN
    END
    'Housekeeping' : BEGIN
        CASE datatype OF 
        'Auxiliary' : OPENR,unit,path+AUX_FILENAME,/GET_LUN
        'SFDU' : OPENR,unit,path+SFDU_FILENAME,/GET_LUN
        'Subcom' : OPENR,unit,path+HSKPSUBCOM_FILENAME,/GET_LUN
        'Analog/Digital' : OPENR,unit,path+HSKPANALOGDIG_FILENAME,/GET_LUN
        'Commands' : OPENR,unit,path+HSKPCMD_FILENAME,/GET_LUN
        'Mag' : OPENR,unit,path+MAG_FILENAME,/GET_LUN
		ELSE : PRINT,'Failure to match datatype '+datatype
        ENDCASE 
    END
    ENDCASE 

    c = ''
    READF,unit,c
    channellist = STRSPLIT(c,' ',/EXTRACT)
    CLOSE,unit
    FREE_LUN,unit

RETURN,channellist
END
