;+
; NAME:
;	PDS_GET_PHITHETA_DEG
;
; PURPOSE:
;	Return the phi and theta values as shift from center of image.
;   
; NOTE: 
;
; CATEGORY:
;	Correction Routine 
;
; CALLING SEQUENCE:
;	PDS_GET_PHITHETA_DEG, imagesize, phi, theta, az_shift, el_shift
;
; INPUTS:
;
;   imagesize   size in pixels of image
;   phi         phi offset of image
;   theta       theta offset of image
;
; RETURNS
;   az_shift    shift in degrees in azimuth from center of image
;   el_shift    shift in degrees in elevation from the center of image

; KEYWORD PARAMETERS:
;
;
;                       Copyright (C) 2004
; The Johns Hopkins University Applied Physics Laboratory (JHU/APL)
;                       All rights reserved
;
; This material may be used, modified or reproduced by or for the
; U.S. Government pursuant to the license rights granted under
; the clauses at DFARS 252.227-7013/7014.
;
; CREATION:
;       11 Nov 2005, M.B. Kusterer 
;
; MODIFICATION HISTORY:
;       22 Oct 2008, M.B. Kusterer Added case for larger images from motion averaging
;-
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
PRO PDS_GET_PHITHETA_DEG, imagesize, phi, theta, az_shift, el_shift

    IF imagesize LT 65 THEN BEGIN
        CASE imagesize OF 
        8: BEGIN
            az_normal = 4.
            el_normal = 2.
            az_deg_p_pix = 180./16.
            el_deg_p_pix = 180./12.
        END 
        16: BEGIN
            az_normal = 8.
            el_normal = 4.
            az_deg_p_pix = 180./32.
            el_deg_p_pix = 180./24.
        END 
        32: BEGIN
            az_normal = 16.
            el_normal = 8.
            az_deg_p_pix = 180./64.
            el_deg_p_pix = 180./48.
        END 
        64: BEGIN
            az_normal = 32.
            el_normal = 16.
            az_deg_p_pix = 180./128.
            el_deg_p_pix = 180./96.
        END
        ENDCASE
        az_shift = (phi - az_normal)*az_deg_p_pix   ;in degrees
        el_shift = (theta - el_normal)*el_deg_p_pix ;in degrees
    ENDIF ELSE BEGIN
        az_shift = 0.
        el_shift = 0.
    ENDELSE

RETURN
END
