;+
; NAME:
;	PDS_READ_INCA_BKGROUND
;
; PURPOSE:
;	Read in the INCA image TOF plots background
;
; NOTE:
;	This routine depends on the environmental variable MIMICAL_NAME being set to the 
;	mimi calibration file. This is done in the setup.pro routine. The user should edit 
;	the setup file to point to their paths. See MIMI website for files
;					http://cassini-mimi.jhuapl.edu/data_auxiliary.html
;
;
; CATEGORY:
;	Read routine. 
;
; CALLING SEQUENCE:
;	status = PDS_READ_INCA_BKGROUND(start_et, cbackgrounds)
;
; INPUTS:
;   start_et  Epheemris time
;
;
; OUTPUTS:
;   backgrounds   {structure, high
;
; KEYWORD PARAMETERS:

;                       Copyright (C) 2011
; The Johns Hopkins University Applied Physics Laboratory (JHU/APL)
;                       All rights reserved
;
; This material may be used, modified or reproduced by or FOR the
; U.S. Government pursuant to the license rights granted under
; the clauses at DFARS 252.227-7013/7014.
;
; CREATION:
;       20 May 2004, M.B. Kusterer 
;
; MODIFICATION HISTORY:
;       16 Jan 2008, M.B. Kusterer Took comment lines out of background files
;       11 Sept 2009, M.B. Kusterer 	Added units to PDS_READ_INCA_BKGROUND
;       03 June 2011, M.B. Kusterer 	For PDS version, use MIMICAL_NAME env var to get filename
;           took out calibdir parameter
;       12 Nov 2012, M.B. Kusterer Changed from using delta [13] to midpoint [14] to get the value.
;		This matches version of MIMI calibration file 10 and higher.
;-
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
PRO TEST_PRIBK

;this test routine only works inside MIMI team machines, it is for comparing
;between mimi software and mimi pds software

	;s=utc2et('1999-001T00:00:00',et)
	s=utc2et('2010-079T00:00:00',et)
	;units = 'counts/s'
	;iunits=1
	;units = 'counts/(cm*s*sr)'
	;iunits=2
	units = 'counts/(cm*s*sr*Kev)'
	iunits=3
	s = PDS_READ_INCA_BKGROUND(et, ew, units)
	s = READ_INCA_BKGROUND(et, altew, iunits)
	tags = tag_names(ew)
	for n=0,n_tags(ew)-1 DO BEGIN
		for t=0,N_ELEMENTS(ew.(n))-1 DO begin
			print,tags[n],' n ',n,' ',ew.(n)[t],' ',altew.(n)[t]
		endfor
	endfor

RETURN
END

FUNCTION PDS_READ_INCA_BKGROUND, start_et, backgrounds, units

    backgrounds = {$
                        high_time_LowTOF:FLTARR(2),$    ;[0] neutral, [1] ion
                        high_time_HighTOF:FLTARR(2),$;[0] neutral, [1] ion
                        high_spat_LowTOF_H:0.0,$
                        high_spat_HighTOF_H:0.0,$
                        high_spat_LowTOF_O:0.0,$
                        high_spat_HighTOF_O:0.0,$
                        high_mTOF_H:FLTARR(2,8),$;[0,*] neutral, [1] ion
                        high_mTOF_O:FLTARR(2,8)$;[0,*] neutral, [1] ion
                     }

    status = 0
	usefile = GETENV('MIMICAL_NAME')
	print,'Using MIMI calibration file '+usefile
    OPENR,lun,usefile,/GET_LUN, ERROR = status
    IF (status lt 0) then begin
        PRINT,'PDS_READ_INCA_BW: Can not read from ' + usefile
		RETURN,-1
    ENDIF ELSE BEGIN
        buff = ''
        READF,lun,buff
        WHILE (NOT EOF(lun)) DO BEGIN
            READF,lun,buff
			buff = CORRECTEMPTYBUFF(buff)
            data = STRSPLIT(buff,',',/EXTRACT)
			
			IF N_ELEMENTS(data) GE 15 THEN BEGIN
			
            	scet = YEARDDAY2UTC(FIX(data[6]),DOUBLE(data[7]))
            	scet2 = YEARDDAY2UTC(FIX(data[8]),DOUBLE(data[9]))
            	s = UTC2ET([scet,scet2], et) 

    			;;;;;;;;;;;;;;;;;;;;;;;;;;
				; high time resolution
    			;;;;;;;;;;;;;;;;;;;;;;;;;;
					
				IF STRMATCH(data[0],'BACKGROUND') EQ 1 AND STRMATCH(data[1],'IMG') EQ 1 AND $
					STRMATCH(data[2],'INCA') EQ 1  AND STRMATCH(data[3],'TIME - TOF') EQ 1 AND $
					STRMATCH(data[10],units) EQ 1 THEN BEGIN
					IF start_et[0] GE et[0] THEN BEGIN
						IF STRMATCH(data[5],'Neutrals') EQ 1 THEN BEGIN
                    		IF STRMATCH(data[4],'0') EQ 1 THEN backgrounds.high_time_LowTOF[0] = data[14]
                    		IF STRMATCH(data[4],'7') EQ 1 THEN backgrounds.high_time_HighTOF[0] = data[14]
            			ENDIF ELSE IF STRMATCH(data[5],'Ions') EQ 1 THEN BEGIN
                    		IF STRMATCH(data[4],'0') EQ 1 THEN backgrounds.high_time_LowTOF[1] = data[14]
                    		IF STRMATCH(data[4],'7') EQ 1 THEN backgrounds.high_time_HighTOF[1] = data[14]
            			ENDIF
            		ENDIF
            	ENDIF

    			;;;;;;;;;;;;;;;;;;;;;;;;;;
				; high spatial resolution
    			;;;;;;;;;;;;;;;;;;;;;;;;;;
				IF STRMATCH(data[0],'BACKGROUND') EQ 1 AND STRMATCH(data[1],'IMG') EQ 1 AND $
					STRMATCH(data[2],'INCA') EQ 1  AND STRMATCH(data[3],'SPATIAL - TOF') EQ 1 AND $
					STRMATCH(data[10],units) EQ 1 THEN BEGIN
					IF start_et[0] GE et[0] THEN BEGIN
						IF STRMATCH(data[5],'H+') EQ 1 THEN BEGIN
                    		IF STRMATCH(data[4],'0') EQ 1 THEN backgrounds.high_spat_LowTOF_H = data[14]
                    		IF STRMATCH(data[4],'7') EQ 1 THEN backgrounds.high_spat_HighTOF_H = data[14]
            			ENDIF ELSE IF STRMATCH(data[5],'Ox') EQ 1 THEN BEGIN
                    		IF STRMATCH(data[4],'0') EQ 1 THEN backgrounds.high_spat_LowTOF_O = data[14]
                    		IF STRMATCH(data[4],'7') EQ 1 THEN backgrounds.high_spat_HighTOF_O = data[14]
            			ENDIF
            		ENDIF
            	ENDIF

    			;;;;;;;;;;;;;;;;;;;;;;;;;;
				; high mTOF resolution - neutral
    			;;;;;;;;;;;;;;;;;;;;;;;;;;
				IF STRMATCH(data[0],'BACKGROUND') EQ 1 AND STRMATCH(data[1],'IMG') EQ 1 AND $
					STRMATCH(data[2],'INCA') EQ 1  AND STRMATCH(data[3],'NEU - TOF') EQ 1 AND $
					STRMATCH(data[10],units) EQ 1 THEN BEGIN
					IF start_et[0] GE et[0] THEN BEGIN
						IF STRMATCH(data[5],'H+') EQ 1 THEN BEGIN
							FOR n=0,7 DO BEGIN
								strn = NUM2STR(n)
                    			IF STRMATCH(data[4],strn) EQ 1 THEN backgrounds.high_mTOF_H[0,n] = data[14]
							ENDFOR
            			ENDIF ELSE IF STRMATCH(data[5],'Ox') EQ 1 THEN BEGIN
							FOR n=0,7 DO BEGIN
								strn = NUM2STR(n)
                    			IF STRMATCH(data[4],strn) EQ 1 THEN backgrounds.high_mTOF_O[0,n] = data[14]
							ENDFOR
            			ENDIF
						IF data[4] EQ '0' THEN BEGIN
						for p=0,N_ELEMENTS(data)-1 DO print,p,' ',data[p]
						ENDIF
            		ENDIF
            	ENDIF
    			;;;;;;;;;;;;;;;;;;;;;;;;;;
				; high mTOF resolution - ions
    			;;;;;;;;;;;;;;;;;;;;;;;;;;
				IF STRMATCH(data[0],'BACKGROUND') EQ 1 AND STRMATCH(data[1],'IMG') EQ 1 AND $
					STRMATCH(data[2],'INCA') EQ 1  AND STRMATCH(data[3],'ION - TOF') EQ 1 AND $
					STRMATCH(data[10],units) EQ 1 THEN BEGIN
					IF start_et[0] GE et[0] THEN BEGIN
						IF STRMATCH(data[5],'H+') EQ 1 THEN BEGIN
							FOR n=0,7 DO BEGIN
								strn = NUM2STR(n)
                    			IF STRMATCH(data[4],strn) EQ 1 THEN backgrounds.high_mTOF_H[1,n] = data[14]
							ENDFOR
            			ENDIF ELSE IF STRMATCH(data[5],'Ox') EQ 1 THEN BEGIN
							FOR n=0,7 DO BEGIN
								strn = NUM2STR(n)
                    			IF STRMATCH(data[4],strn) EQ 1 THEN backgrounds.high_mTOF_O[1,n] = data[14]
							ENDFOR
            			ENDIF
            		ENDIF
            	ENDIF
            ENDIF
        ENDWHILE
        FREE_LUN,lun

    ENDELSE

    
RETURN,status
END



