;+
; NAME:
;	PDS_READ_INCA_BW_WIDTHS
;
; PURPOSE:
;	Read in the INCA image energy band widths (bw files)
;
; NOTE:
;	This routine depends on the environmental variable MIMICAL_NAME being set to the 
;	mimi calibration file. This is done in the setup.pro routine. The user should edit 
;	the setup file to point to their paths. See MIMI website for files
;					http://cassini-mimi.jhuapl.edu/data_auxiliary.html
;
;
; CATEGORY:
;	Read routine. 
;
; CALLING SEQUENCE:
;	status = PDS_READ_INCA_BW_WIDTHS(start_et, energy_widths, energy_ranges)
;
; INPUTS:
;   start_et  Epheemris time
;
;
; OUTPUTS:
;   energy_widths   {structure, high
;
; KEYWORD PARAMETERS:

;
; CREATION:
;       20 May 2004, M.B. Kusterer 
;
; MODIFICATION HISTORY:
;       03 June 2011, M.B. Kusterer 	For PDS version, use MIMICAL_NAME env var to get filename
;           took out calibdir parameter
;-
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
PRO TEST_PRIB

;this test routine only works inside MIMI team machines, it is for comparing
;between mimi software and mimi pds software

	;s=utc2et('1999-001T00:00:00',et)
	;s=utc2et('2000-338T00:00:00',et)
	;s=utc2et('2003-066T00:00:00',et)
	;s=utc2et('2004-079T00:00:00',et)
	s=utc2et('2010-079T00:00:00',et)
	s = PDS_READ_INCA_BW(et, ew, er)
	s = READ_INCA_BW_WIDTHS(et, altew)
	tags = tag_names(ew)
	;print,'widths'
	;for n=0,n_tags(ew)-1 DO BEGIN
	;	for t=0,N_ELEMENTS(ew.(n))-1 DO begin
	;		print,tags[n],' n ',n,' ',ew.(n)[t],' ',altew.(n)[t]
	;	endfor
	;endfor

	print,'ranges'
	s = READ_INCA_BW_RANGES(et, alter)
	tags = tag_names(er)
	for n=0,n_tags(er)-1 DO BEGIN
		for t=0,N_ELEMENTS(er.(n))-1 DO begin
			if strpos(strlowcase(tags[n]),'mtof') NE -1 and  strpos(strlowcase(tags[n]),'neu') NE -1 then begin
			print,tags[n],' n ',n,' ',er.(n)[t],' ',alter.(n)[t]
			endif
		endfor
	endfor
RETURN
END

FUNCTION PDS_READ_INCA_BW, start_et, energy_widths, energy_ranges

    energy_widths = {$
                        high_time_LowTOF_neu:0.,$
                        high_time_HighTOF_neu:0.,$
                        high_time_LowTOF_ion:0.,$
                        high_time_HighTOF_ion:0.,$
                        high_spat_LowTOF_H:0.,$
                        high_spat_HighTOF_H:0.,$
                        high_spat_LowTOF_O:0.,$
                        high_spat_HighTOF_O:0.,$
                        high_mTOF_H_neu:FLTARR(8),$
                        high_mTOF_O_neu:FLTARR(8),$
                        high_mTOF_H_ion:FLTARR(8),$
                        high_mTOF_O_ion:FLTARR(8)$
                     }

    energy_ranges = {$
                        high_time_LowTOF_neu:FLTARR(2),$
                        high_time_HighTOF_neu:FLTARR(2),$
                        high_time_LowTOF_ion:FLTARR(2),$
                        high_time_HighTOF_ion:FLTARR(2),$
                        high_spat_LowTOF_H:FLTARR(2),$
                        high_spat_HighTOF_H:FLTARR(2),$
                        high_spat_LowTOF_O:FLTARR(2),$
                        high_spat_HighTOF_O:FLTARR(2),$
                        high_mTOF_H_neu:FLTARR(2,8),$
                        high_mTOF_O_neu:FLTARR(2,8),$
                        high_mTOF_H_ion:FLTARR(2,8),$
                        high_mTOF_O_ion:FLTARR(2,8)$
                     }
    status = 0
    
    

	usefile = GETENV('MIMICAL_NAME')
	print,'Using MIMI calibration file '+usefile
    OPENR,lun,usefile,/GET_LUN, ERROR = status
    IF (status lt 0) then begin
        PRINT,'PDS_READ_INCA_BW: Can not read from ' + usefile
		RETURN,-1
    ENDIF ELSE BEGIN
        buff = ''
        READF,lun,buff
        WHILE (NOT EOF(lun)) DO BEGIN
            READF,lun,buff
			buff = CORRECTEMPTYBUFF(buff)
			
            data = STRSPLIT(buff,',',/EXTRACT)
			IF N_ELEMENTS(data) GE 15 THEN BEGIN

				;;;;;;;;;;;;;;;;;;;;;;;;;;
				;high time resolution 
				;;;;;;;;;;;;;;;;;;;;;;;;;;
				;print,STRJOIN(data[0:3],' ')
				IF STRMATCH(data[0],'ENERGY') EQ 1 AND STRMATCH(data[1],'IMG') EQ 1 AND $
					STRMATCH(data[2],'INCA') EQ 1  AND STRMATCH(data[3],'TIME - TOF') EQ 1 THEN BEGIN

            		scet = YEARDDAY2UTC(FIX(data[6]),DOUBLE(data[7]))
            		scet2 = YEARDDAY2UTC(FIX(data[8]),DOUBLE(data[9]))
            		s=UTC2ET([scet,scet2], et) 

            		IF start_et[0] GE et[0] AND start_et[0] LE et[1] THEN BEGIN
						IF STRMATCH(data[5],'Neutrals') EQ 1 THEN BEGIN
                			IF STRMATCH(data[4],'0') EQ 1 THEN BEGIN
								energy_widths.high_time_LowTOF_neu = DOUBLE(data[13])
								energy_ranges.high_time_LowTOF_neu = DOUBLE(data[11:12])
                			ENDIF
							IF STRMATCH(data[4],'7') EQ 1 THEN BEGIN
								 energy_widths.high_time_HighTOF_neu = DOUBLE(data[13])
								energy_ranges.high_time_HighTOF_neu = DOUBLE(data[11:12])
                			ENDIF
            			ENDIF ELSE IF STRMATCH(data[5],'Ions') EQ 1 THEN BEGIN
                			IF STRMATCH(data[4],'0') EQ 1 THEN BEGIN
								 energy_widths.high_time_LowTOF_ion =  DOUBLE(data[13])
								energy_ranges.high_time_LowTOF_ion = DOUBLE(data[11:12])
                			ENDIF
                			IF STRMATCH(data[4],'7') EQ 1 THEN BEGIN
								 energy_widths.high_time_HighTOF_ion =  DOUBLE(data[13])
								energy_ranges.high_time_HighTOF_ion = DOUBLE(data[11:12])
                			ENDIF
						ENDIF
					ENDIF

        		ENDIF
				;print,'high_time_LowTOF_neu ',energy_widths.high_time_LowTOF_neu
				;print,'high_time_HighTOF_neu ',energy_widths.high_time_HighTOF_neu
				;print,'high_time_LowTOF_ion ',energy_widths.high_time_LowTOF_ion
				;print,'high_time_HighTOF_ion ',energy_widths.high_time_HighTOF_ion
				;print,'high_time_LowTOF_neu ',energy_ranges.high_time_LowTOF_neu
				;print,'high_time_HighTOF_neu ',energy_ranges.high_time_HighTOF_neu
				;print,'high_time_LowTOF_ion ',energy_ranges.high_time_LowTOF_ion
				;print,'high_time_HighTOF_ion ',energy_ranges.high_time_HighTOF_ion

				;;;;;;;;;;;;;;;;;;;;;;;;;;
				;high spatial  resolution 
				;;;;;;;;;;;;;;;;;;;;;;;;;;
				IF STRMATCH(data[0],'ENERGY') EQ 1 AND STRMATCH(data[1],'IMG') EQ 1 AND $
					STRMATCH(data[2],'INCA') EQ 1  AND STRMATCH(data[3],'SPATIAL - TOF') EQ 1 THEN BEGIN

            		scet = YEARDDAY2UTC(FIX(data[6]),DOUBLE(data[7]))
            		scet2 = YEARDDAY2UTC(FIX(data[8]),DOUBLE(data[9]))
            		s=UTC2ET([scet,scet2], et) 
					
            		IF start_et[0] GE et[0] AND start_et[0] LE et[1] THEN BEGIN
						IF STRMATCH(data[5],'H+') EQ 1 THEN BEGIN
                			IF STRMATCH(data[4],'0') EQ 1 THEN BEGIN
								energy_widths.high_spat_LowTOF_H = DOUBLE(data[13])
								energy_ranges.high_spat_LowTOF_H = DOUBLE(data[11:12])
							ENDIF
                			IF STRMATCH(data[4],'7') EQ 1 THEN BEGIN
								energy_widths.high_spat_HighTOF_H = DOUBLE(data[13])
								energy_ranges.high_spat_HighTOF_H = DOUBLE(data[11:12])
							ENDIF
            			ENDIF ELSE IF STRMATCH(data[5],'Ox') EQ 1 THEN BEGIN
							IF STRMATCH(data[4],'0') EQ 1 THEN BEGIN
								energy_widths.high_spat_LowTOF_O =  DOUBLE(data[13])
								energy_ranges.high_spat_LowTOF_O = DOUBLE(data[11:12])
							ENDIF
                			IF STRMATCH(data[4],'7') EQ 1 THEN BEGIN
								energy_widths.high_spat_HighTOF_O =  DOUBLE(data[13])
								energy_ranges.high_spat_HighTOF_O = DOUBLE(data[11:12])
							ENDIF
						ENDIF
					ENDIF

        		ENDIF
				;print,'high_spat_LowTOF_H  ',energy_widths.high_spat_LowTOF_H
				;print,'high_spat_HighTOF_H ',energy_widths.high_spat_HighTOF_H
				;print,'high_spat_LowTOF_O  ',energy_widths.high_spat_LowTOF_O
				;print,'high_spat_HighTOF_O ',energy_widths.high_spat_HighTOF_O
				;print,'high_spat_LowTOF_H  ',energy_ranges.high_spat_LowTOF_H
				;print,'high_spat_HighTOF_H ',energy_ranges.high_spat_HighTOF_H
				;print,'high_spat_LowTOF_O  ',energy_ranges.high_spat_LowTOF_O
				;print,'high_spat_HighTOF_O ',energy_ranges.high_spat_HighTOF_O

				;;;;;;;;;;;;;;;;;;;;;;;;;;
				;high mTOF resolution 
				;;;;;;;;;;;;;;;;;;;;;;;;;;
				IF STRMATCH(data[0],'ENERGY') EQ 1 AND STRMATCH(data[1],'IMG') EQ 1 AND $
					STRMATCH(data[2],'INCA') EQ 1  AND STRMATCH(data[3],'NEU - TOF') EQ 1 THEN BEGIN

            		scet = YEARDDAY2UTC(FIX(data[6]),DOUBLE(data[7]))
            		scet2 = YEARDDAY2UTC(FIX(data[8]),DOUBLE(data[9]))
            		s=UTC2ET([scet,scet2], et) 

            		IF start_et[0] GE et[0] AND start_et[0] LE et[1] THEN BEGIN
						IF STRMATCH(data[5],'H+') EQ 1 THEN BEGIN
							FOR n=0,7 DO BEGIN
								strn = NUM2STR(n)
                				IF STRMATCH(data[4],strn) EQ 1 THEN BEGIN
								 	energy_widths.high_mTOF_H_neu[n] = DOUBLE(data[13])
									energy_ranges.high_mTOF_H_neu[*,n] = DOUBLE(data[11:12])
								ENDIF
							ENDFOR
            			ENDIF ELSE IF STRMATCH(data[5],'Ox') EQ 1 THEN BEGIN
							FOR n=0,7 DO BEGIN
								strn = NUM2STR(n)
                				IF STRMATCH(data[4],strn) EQ 1 THEN BEGIN
								 	energy_widths.high_mTOF_O_neu[n] = DOUBLE(data[13])
									energy_ranges.high_mTOF_O_neu[*,n] = DOUBLE(data[11:12])
								ENDIF
							ENDFOR
						ENDIF
					ENDIF

        		ENDIF
				IF STRMATCH(data[0],'ENERGY') EQ 1 AND STRMATCH(data[1],'IMG') EQ 1 AND $
					STRMATCH(data[2],'INCA') EQ 1  AND STRMATCH(data[3],'ION - TOF') EQ 1 THEN BEGIN

            		scet = YEARDDAY2UTC(FIX(data[6]),DOUBLE(data[7]))
            		scet2 = YEARDDAY2UTC(FIX(data[8]),DOUBLE(data[9]))
            		s=UTC2ET([scet,scet2], et) 

            		IF start_et[0] GE et[0] AND start_et[0] LE et[1] THEN BEGIN
						IF STRMATCH(data[5],'H+') EQ 1 THEN BEGIN
							FOR n=0,7 DO BEGIN
								strn = NUM2STR(n)
                				IF STRMATCH(data[4],strn) EQ 1 THEN BEGIN
								 	energy_widths.high_mTOF_H_ion[n] = DOUBLE(data[13])
									energy_ranges.high_mTOF_H_ion[*,n] = DOUBLE(data[11:12])
								ENDIF
							ENDFOR
            			ENDIF ELSE IF STRMATCH(data[5],'Ox') EQ 1 THEN BEGIN
							FOR n=0,7 DO BEGIN
								strn = NUM2STR(n)
                				IF STRMATCH(data[4],strn) EQ 1 THEN BEGIN
								 	energy_widths.high_mTOF_O_ion[n] = DOUBLE(data[13])
									energy_ranges.high_mTOF_O_ion[*,n] = DOUBLE(data[11:12])
								ENDIF
							ENDFOR
						ENDIF
					ENDIF
        		ENDIF
        	ENDIF
        ENDWHILE
        FREE_LUN,lun

    ENDELSE
;print,'high_mTOF_H_neu '
; for i=0,7 do print,'tof ',i,' ',energy_widths.high_mTOF_H_neu[i]
; print,'high_mTOF_O_neu '
; for i=0,7 do print,'tof ',i,' ',energy_widths.high_mTOF_O_neu[i]

;print,'high_mTOF_H_ion '
; for i=0,7 do print,'tof ',i,' ',energy_widths.high_mTOF_H_ion[i]
; print,'high_mTOF_O_ion '
 ;for i=0,7 do print,'tof ',i,' ',energy_widths.high_mTOF_O_ion[i]

;print,'high_mTOF_H_neu '
; for i=0,7 do print,'tof ',i,' ',energy_ranges.high_mTOF_H_neu[i]
; print,'high_mTOF_O_neu '
; for i=0,7 do print,'tof ',i,' ',energy_ranges.high_mTOF_O_neu[i]

;print,'high_mTOF_H_ion '
; for i=0,7 do print,'tof ',i,' ',energy_ranges.high_mTOF_H_ion[i]
; print,'high_mTOF_O_ion '
; for i=0,7 do print,'tof ',i,' ',energy_ranges.high_mTOF_O_ion[i]


    
RETURN,status
END



