;+
; NAME:
;   PDS_READ_MIMICAL
;
; PURPOSE:
;   This routine reads the lemms, chems and inca calibration numbers. 
;	The first set of calibration numbers in the file that match the time will be used. That way
;	older numbers can be retained as long as they follow later in the file.
;	For all but the lemms background, only one set of numbers that match will be returned, 
;	for lemms background, all that match will be returned.
;
;
; INPUTS:
;    start_et      Ephemeris time to save data
;
;   Uses env var MIMICAL_NAME to get calibration filename, this is set in the setup.pro file
;   Obtain gzipped tar set from  "http://cassini-mimi.jhuapl.edu/data_auxiliary.html". 
;
; OUTPUTS:
;    lemms   Lemms structure
;    chems   Chems structure
;	 inca    Inca structure
;
;                       Copyright (C) 2011
; The Johns Hopkins University Applied Physics Laboratory (JHU/APL)
;                       All rights reserved
;
; This material may be used, modified or reproduced by or FOR the
; U.S. Government pursuant to the license rights granted under
; the clauses at DFARS 252.227-7013/7014.
;
; CREATION:
;
;   16 Aug 2010    M.B. Kusterer Original
;
; MODIFICATION HISTORY:
;-
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

FUNCTION PDS_READ_MIMICAL ,startutc, stoputc, lemms, chems, inca,$
									MIMI_CAL_FILE=MIMI_CAL_FILE

@pds_data_hdr_h
@pds_image_hdr_h
@pds_mimical_hdr_h	;has lemms_sensor,lemms_particles,lemms_pha_chans,oddchan_name,lemms_datatypes,
						;LEMMS_NUM_PARTICLES,chems_sensor,chems_particles,purposes,chems_datatypes,chems_channels,
						;chems_indextypes,chems_particletypes,nchems_particles,
						;inca_sensor,inca_particles,inca_datatypes,inca_channels,inca_charges,
						;inca_species,inca_spat_tof

	s=UTC2ET(startutc,start_et)
	s=UTC2ET(stoputc,stop_et)
    
; Lemms Calibration Structure
fcalib_struct = {$
        filled:LONARR(3)} 
calib_struct = {$
        purpose:'',$
        datatype:'',$
        sensor:'',$
        channel:'',$
        index:'',$
        particle:'',$
        units:'',$
         low:0D,$
         high:0D,$
         delta:0D,$
         midpoint:0D,$
         geometry_factor:0D,$
         efficiency:0D,$
         max_calib_level:0L,$   ;maximum calibration level available
         source:'',$
		 startutc:'',$
		 stoputc:''}
            ; 0=counts, 1=counts/sec , 2=integral intensitiy, 3=dIFferential intensity
    
	flemms = {normal:REPLICATE(fcalib_struct,LEMMS_NUM_PARTICLES, MAX_LEMMS_NORMAL_CNTRS),$
        priority:REPLICATE(fcalib_struct,LEMMS_NUM_PARTICLES, MAX_LEMMS_NORMAL_CNTRS),$ ;allow any FOR priority
        pha:REPLICATE(fcalib_struct,MAX_LEMMSPHA_NORM+MAX_LEMMSPHA_PRIO,MAX_LEMMSPHA_DET),$
		background:REPLICATE(fcalib_struct,MAX_LEMMS_NORMAL_CNTRS,LEMMS_NUM_PARTICLES,LEMMS_NUM_BACKGROUNDS),$
	    phabackground:REPLICATE(fcalib_struct,MAX_LEMMSPHA_NORM+MAX_LEMMSPHA_PRIO,MAX_LEMMSPHA_DET,LEMMS_NUM_BACKGROUNDS)}
       
    lemms = {$
        normal:REPLICATE(calib_struct,LEMMS_NUM_PARTICLES, MAX_LEMMS_NORMAL_CNTRS),$
        priority:REPLICATE(calib_struct,LEMMS_NUM_PARTICLES, MAX_LEMMS_NORMAL_CNTRS),$ ;allow any FOR priority
        pha:REPLICATE(calib_struct,MAX_LEMMSPHA_NORM+MAX_LEMMSPHA_PRIO,MAX_LEMMSPHA_DET),$
		background:REPLICATE(calib_struct,MAX_LEMMS_NORMAL_CNTRS,LEMMS_NUM_PARTICLES,LEMMS_NUM_BACKGROUNDS),$
		phabackground:REPLICATE(calib_struct,MAX_LEMMSPHA_NORM+MAX_LEMMSPHA_PRIO,MAX_LEMMSPHA_DET,LEMMS_NUM_BACKGROUNDS),$
        lemms_particles:lemms_particles}
    
; Chems Calibration Structure 
		fchems = {$
        mass:REPLICATE(fcalib_struct,MAX_SCIENCEBASIC_RATE),$
        mass_charge:REPLICATE(fcalib_struct,MAX_SCIENCEBASIC_RATE),$
        dpps_sci:REPLICATE(fcalib_struct,MAX_DPPS),$
        dpps_sci_eff:REPLICATE(fcalib_struct,MAX_DPPS,N_ELEMENTS(chems_particles)),$
        dpps_pha:REPLICATE(fcalib_struct,MAX_DPPS),$
        telescope_gf:REPLICATE(fcalib_struct,4),$
        telescope_fov:REPLICATE(fcalib_struct,1)}
		
    chems = {$
        mass:REPLICATE(calib_struct,MAX_SCIENCEBASIC_RATE),$
        mass_charge:REPLICATE(calib_struct,MAX_SCIENCEBASIC_RATE),$
        dpps_sci:REPLICATE(calib_struct,MAX_DPPS),$
        dpps_sci_eff:REPLICATE(CREATE_STRUCT(calib_struct,'ADNL_PART',''),MAX_DPPS,N_ELEMENTS(chems_particles)),$
        dpps_pha:REPLICATE(calib_struct,MAX_DPPS),$
        telescope_gf:REPLICATE(calib_struct,4),$
        telescope_fov:REPLICATE(calib_struct,1)}
        
;INCA Calibration Structure
    inca = {$
        image:{spatial:REPLICATE(calib_struct,NUM_SPATIAL_TOF,NUM_SPATIAL_SPECIES),$
            time:REPLICATE(calib_struct,NUM_TIME_TOF,NUM_TIME_CHARGES),$
            tof:REPLICATE(calib_struct,NUM_TOF_TOF,NUM_TOF_SPECIES,NUM_TOF_CHARGES)},$
        background:{spatial:REPLICATE(calib_struct,NUM_SPATIAL_TOF,NUM_SPATIAL_SPECIES),$
            time:REPLICATE(calib_struct,NUM_TIME_TOF,NUM_TIME_CHARGES),$
            tof:REPLICATE(calib_struct,NUM_TOF_TOF,NUM_TOF_SPECIES,NUM_TOF_CHARGES)},$
        enuc_b:calib_struct,$
        geometry:REPLICATE(calib_struct,NUM_INCA_GF_DATATYPES,NUM_INCA_GF_SPECIES)}
        
    finca = {$
        image:{spatial:REPLICATE(fcalib_struct,NUM_SPATIAL_TOF,NUM_SPATIAL_SPECIES),$
            time:REPLICATE(fcalib_struct,NUM_TIME_TOF,NUM_TIME_CHARGES),$
            tof:REPLICATE(fcalib_struct,NUM_TOF_TOF,NUM_TOF_SPECIES,NUM_TOF_CHARGES)},$
        background:{spatial:REPLICATE(fcalib_struct,NUM_SPATIAL_TOF,NUM_SPATIAL_SPECIES),$
            time:REPLICATE(fcalib_struct,NUM_TIME_TOF,NUM_TIME_CHARGES),$
            tof:REPLICATE(fcalib_struct,NUM_TOF_TOF,NUM_TOF_SPECIES,NUM_TOF_CHARGES)},$
        enuc_b:fcalib_struct,$
        geometry:REPLICATE(fcalib_struct,NUM_INCA_GF_DATATYPES,NUM_INCA_GF_SPECIES)}
        
    PDS_ZERO_MIMI_CAL,lemms, flemms, chems, fchems, inca, finca 

    ;read in channel labels
    lemmsacc_chararr = PDS_GET_LISTOFCHANS(start_et, 'LEMMS','Accumulator Rates')
    ;lemmspha_chararr = PDS_GET_LISTOFCHANS(start_et, 'LEMMS','PHA Data')
    chemssci_chararr = PDS_GET_LISTOFCHANS(start_et, 'CHEMS','Basic & Science')
    ;chemspha_chararr = PDS_GET_LISTOFCHANS(start_et, 'CHEMS','PHA Events')

    	;Read labels file to find the current mimi_calibration file   
    
	IF N_ELEMENTS(MIMI_CAL_FILE) GT 0 THEN BEGIN	;use passed in filename
		file = MIMI_CAL_FILE
	ENDIF ELSE BEGIN	;find calibration file based on configuration files
    	file = GETENV('MIMICAL_NAME')
    ENDELSE
	
    OPENR,lun,file,/GET_LUN, ERROR = status
    IF (status lt 0) then begin
        MESSAGE,/CONT,'Can not read from ' + file
    ENDIF ELSE BEGIN
        buff = ''
        READF,lun,buff  ;read headers and discard
        
        WHILE (NOT EOF(lun)) DO BEGIN
        
            ;read in data 
            READF,lun,buff  ;read headers and discard
            IF buff NE '' THEN BEGIN
            
                data = STRSPLIT(buff,',',/EXTRACT,/PRESERVE_NULL)
                ndata = N_ELEMENTS(data)
                purpose = data[0] 
                datatype = data[1] 
                sensor = data[2] 
                channel = data[3]
                strindex = data[4] 
                index = (data[4] EQ '' OR data[4] EQ 'Triple' OR data[4] EQ 'Double') ? 0 : long(data[4]) 
                particle = data[5]
                startyear = long(data[6])
                startdoy = double(data[7])
                stopyear = long(data[8])
                stopdoy = double(data[9])
                units = (ndata GE 11) ? data[10] : ''
                low = (ndata GE 12) ? double(data[11]) : 0.0
                high = (ndata GE 13) ? double(data[12]) : 0.0
                delta = (ndata GE 14) ? double(data[13]) : 0.0
                midpoint = (ndata GE 15) ? double(data[14]) : 0.0
                source = (ndata GE 16) ? data[15] : ''
				
                ;print,purpose,' ',datatype,' ',sensor,' ',channel,' ',index,' ',particle,' ',$
                   ; startyear,' ',startdoy,' ',stopyear,' ',stopdoy,' ',units,' ',low,' ', high,$
                   ; ' ',delta,' ',midpoint,' ',source
               
                IF startyear NE 0 AND stopyear NE 0 THEN BEGIN

                    ;remove " from start and end of strings, was in old file

                    ;purpose = STRMID(purpose,1,STRLEN(purpose)-2)
                    ;datatype = STRMID(datatype,1,STRLEN(datatype)-2)
                    ;sensor = STRMID(sensor,1,STRLEN(sensor)-2)
                    ;channel = STRMID(channel,1,STRLEN(channel)-2)
                    ;particle = STRMID(particle,1,STRLEN(particle)-2)
                    ;units = STRMID(units,1,STRLEN(units)-2)
                    
                    ;switch stupid E2/FS2 which Jerry calls E2_FS2
                    channel = (channel NE oddchan_name[0]) ? channel : oddchan_name[1]
                    
                    channelindex = channel+strindex

               
                    ;convert year, decimal day of year into time string
                    doys = long( startdoy)
                    totalsecs = (startdoy - doys) * 60. * 60. * 24.0;
                    hours = long (totalsecs/(60.0*60.0))
                    totalsecs -= hours*60.0*60.0
                    mins = long (totalsecs/60.0)
                    totalsecs -= mins*60.0
                    secs = long( totalsecs)

                    strstarttime = STRCOMPRESS(STRING(startyear,FORMAT='(I4.4)')+'-'+$
                        STRING(doys,FORMAT='(I3.3)')+'T'+$
                        STRING(hours,FORMAT='(I2.2)')+':'+$
                        STRING(mins,FORMAT='(I2.2)')+':'+$
                        STRING(secs,FORMAT='(I2.2)'),/REMOVE_ALL)
	                result = UTC2ET(strstarttime, calib_start_et)

                    edoys =long( stopdoy)
                    totalsecs = (stopdoy - edoys) * 60. * 60. * 24.0
                    ehours = long( totalsecs/(60.0*60.0))
                    totalsecs -= ehours*60.0*60.0
                    emins = long (totalsecs/60.0)
                    totalsecs -= emins*60.0
                    esecs = long( totalsecs)

                    strstoptime = STRCOMPRESS(STRING(stopyear,FORMAT='(I4.4)')+'-'+$
                        STRING(edoys,FORMAT='(I3.3)')+'T'+$
                        STRING(ehours,FORMAT='(I2.2)')+':'+$
                        STRING(emins,FORMAT='(I2.2)')+':'+$
                        STRING(esecs,FORMAT='(I2.2)'),/REMOVE_ALL)
	                result = UTC2ET(strstoptime, calib_stop_et)

                   ; PRINT, purpose,' ',  datatype,  ' ',sensor,  ' ',channel,  ' ',index,  ' ',channelindex ,$
                            ; ' ',particle,  ' ',startyear,  ' ',startdoy,  ' ',stopyear,  ' ',stopdoy,  $
                           ; ' ',units,  ' ',low,  ' ',high, ' ', delta,  ' ',midpoint,  ' ',strstarttime , $
                           ; ' ',strstoptime
							
                    ;is this start time within the calibration time period FOR this line 
                    IF stop_et GE calib_start_et AND start_et LE calib_stop_et THEN BEGIN
                        IF sensor EQ lemms_sensor AND datatype EQ lemms_datatypes[0] AND $
									purpose EQ purposes[8] THEN BEGIN   ;LeMMS background

                        	;figure out which channel it is
							chan_index = WHERE(lemmsacc_chararr[*] EQ channelindex)
							part_index = WHERE(lemms_particles[*] EQ particle)

							;figure out how far into that set of backgrounds for this time period we are
							iamat = WHERE(flemms.background[chan_index,part_index,*].filled[0] EQ 0)
							iamat = iamat[0]

							IF (chan_index[0] NE -1 AND part_index[0] NE -1 AND $
								iamat NE -1) THEN BEGIN

    							lemms.background[chan_index,part_index,iamat].purpose = purpose
    							lemms.background[chan_index,part_index,iamat].datatype = datatype
    							lemms.background[chan_index,part_index,iamat].sensor = sensor
    							lemms.background[chan_index,part_index,iamat].channel = channel
    							lemms.background[chan_index,part_index,iamat].index = strindex
    							lemms.background[chan_index,part_index,iamat].particle = particle
    							lemms.background[chan_index,part_index,iamat].units = units
    							lemms.background[chan_index,part_index,iamat].low = low
    							lemms.background[chan_index,part_index,iamat].high = high
    							lemms.background[chan_index,part_index,iamat].delta = delta
    							lemms.background[chan_index,part_index,iamat].midpoint = midpoint
    							lemms.background[chan_index,part_index,iamat].source = source
    							lemms.background[chan_index,part_index,iamat].startutc = strstarttime
    							lemms.background[chan_index,part_index,iamat].stoputc = strstoptime
    							flemms.background[chan_index,part_index,iamat].filled[0] = 1
							ENDIF
						ENDIF ELSE IF sensor EQ lemms_sensor AND datatype EQ lemms_datatypes[1] AND $
									purpose EQ purposes[8] THEN BEGIN   ;LeMMS PHA background
                        	;figure out which channel it is
                            chan_index = WHERE(lemms_pha_chans[*] EQ channel)
							
							;figure out how far into that set of backgrounds for this time period we are
							iamat = WHERE(flemms.phabackground[index,chan_index,*].filled[0] EQ 0)
							iamat = iamat[0]

							IF (chan_index[0] NE -1  AND  iamat NE -1) THEN BEGIN

    							lemms.phabackground[index,chan_index,iamat].purpose = purpose
    							lemms.phabackground[index,chan_index,iamat].datatype = datatype
    							lemms.phabackground[index,chan_index,iamat].sensor = sensor
    							lemms.phabackground[index,chan_index,iamat].channel = channel
    							lemms.phabackground[index,chan_index,iamat].index = strindex
    							lemms.phabackground[index,chan_index,iamat].particle = particle
    							lemms.phabackground[index,chan_index,iamat].units = units
    							lemms.phabackground[index,chan_index,iamat].low = low
    							lemms.phabackground[index,chan_index,iamat].high = high
    							lemms.phabackground[index,chan_index,iamat].delta = delta
    							lemms.phabackground[index,chan_index,iamat].midpoint = midpoint
    							lemms.phabackground[index,chan_index,iamat].source = source
    							lemms.phabackground[index,chan_index,iamat].startutc = strstarttime
    							lemms.phabackground[index,chan_index,iamat].stoputc = strstoptime
    							flemms.phabackground[index,chan_index,iamat].filled[0] = 1
							ENDIF ELSE print,'Failure to locate chan index ',channel
                        ENDIF
					ENDIF
					
                    ;is this start time within the calibration time period FOR this line 
                    IF start_et GE calib_start_et AND start_et LE calib_stop_et THEN BEGIN
                        IF (sensor EQ lemms_sensor) THEN BEGIN

                            IF (purpose EQ purposes[0] AND $
								datatype EQ lemms_datatypes[0]) THEN BEGIN   ;LeMMS ENERGY ACC

                                ;figure out which channel it is
                                chan_index = WHERE(lemmsacc_chararr[*] EQ channelindex)
                                part_index = WHERE(lemms_particles[*] EQ particle)

                                IF (part_index[0] NE -1 AND chan_index[0] NE -1) THEN BEGIN   ;energy
                                    IF flemms.normal[part_index,chan_index].filled[0] NE 1 THEN BEGIN
                                        lemms.normal[part_index,chan_index].purpose = purpose
                                        lemms.normal[part_index,chan_index].datatype = datatype
                                        lemms.normal[part_index,chan_index].sensor = sensor
                                        lemms.normal[part_index,chan_index].channel = channel
                                        lemms.normal[part_index,chan_index].index = strindex
                                        lemms.normal[part_index,chan_index].particle = particle
                                        lemms.normal[part_index,chan_index].units = units
                                        lemms.normal[part_index,chan_index].low = low
                                        lemms.normal[part_index,chan_index].high = high
                                        lemms.normal[part_index,chan_index].delta = delta
                                        lemms.normal[part_index,chan_index].midpoint = midpoint
                                        lemms.normal[part_index,chan_index].source = source
                                        flemms.normal[part_index,chan_index].filled[0] = 1
                            			lemms.normal[part_index,chan_index].startutc = strstarttime
                            			lemms.normal[part_index,chan_index].stoputc = strstoptime
                                    ENDIF
								ENDIF ELSE PRINT,'Failure to find lemms energy acc part_index or chan_index '
								
                            ENDIF ELSE IF (purpose EQ purposes[4] AND $
								datatype EQ lemms_datatypes[0]) THEN BEGIN  ;geom factor, do FOR ALL particles, 
																			;but do test that is valid part
                                
								chan_index = WHERE(channelindex EQ lemmsacc_chararr)
                                part_index = WHERE(particle EQ lemms_particles)

                                IF (part_index[0] NE -1 AND chan_index[0] NE -1) THEN BEGIN   
                                   	IF flemms.normal[0,chan_index].filled[1] NE 1 THEN BEGIN
                                        	lemms.normal[*,chan_index].geometry_factor = midpoint
											flemms.normal[*,chan_index].filled[1] = 1
                                    ENDIF
								ENDIF ELSE PRINT,'Failure to find lemms geom acc part_index or chan_index ',part_index,chan_index
								
                            ENDIF ELSE IF (purpose EQ purposes[5] AND $
								datatype EQ lemms_datatypes[0]) THEN BEGIN   ;effic, do FOR all particles, 
																			;but do test that is valid part
								chan_index = WHERE(lemmsacc_chararr[*] EQ channelindex)
                                part_index = WHERE(lemms_particles[*] EQ particle)

                                IF (part_index[0] NE -1 AND chan_index[0] NE -1) THEN BEGIN   
                                        IF flemms.normal[0,chan_index].filled[2] NE 1 THEN BEGIN
                                            lemms.normal[*,chan_index].efficiency = midpoint
                                            flemms.normal[*,chan_index].filled[2] = 1
                                        ENDIF
                                ENDIF ELSE PRINT,'Failure to find lemms effic acc part_index or chan_index '
								
                            ENDIF ELSE IF (purpose EQ purposes[0] AND $
								datatype EQ lemms_datatypes[1]) THEN BEGIN  ;LEMMS ENERGY pha

                                ;figure out which channel it is
                                chan_index = WHERE(lemms_pha_chans[*] EQ channel)

                                i = index
                                IF (chan_index[0] NE -1) THEN BEGIN

                                    IF flemms.pha[i,chan_index].filled[0] NE 1 THEN BEGIN
                                        lemms.pha[i,chan_index].purpose = purpose
                                        lemms.pha[i,chan_index].datatype = datatype
                                        lemms.pha[i,chan_index].sensor = sensor
                                        lemms.pha[i,chan_index].channel = channel
                                        lemms.pha[i,chan_index].index = strindex
                                        lemms.pha[i,chan_index].particle = particle
                                        lemms.pha[i,chan_index].units = units
                                        lemms.pha[i,chan_index].low = low
                                        lemms.pha[i,chan_index].high = high
                                        lemms.pha[i,chan_index].delta = delta
                                        lemms.pha[i,chan_index].midpoint = midpoint
                                        lemms.pha[i,chan_index].source = source
                                        lemms.pha[i,chan_index].startutc = strstarttime
                                        lemms.pha[i,chan_index].stoputc = strstoptime
                                        flemms.pha[i,chan_index].filled[0] = 1
                                    ENDIF
                                ENDIF ELSE PRINT,'Failure to find lemms energy pha chan_index '

                            ENDIF ELSE IF (purpose EQ purposes[4] AND $
								datatype EQ lemms_datatypes[1]) THEN BEGIN   ;PHA geom factor
                                ;figure out which channel it is
                                chan_index = WHERE(lemms_pha_chans[*] EQ channel)

                                i = index
                                IF (chan_index[0] NE -1) THEN BEGIN
                                    IF flemms.pha[i,chan_index].filled[1] NE 1 THEN BEGIN
                                        lemms.pha[i,chan_index].geometry_factor = midpoint
                                        lemms.pha[i,chan_index].efficiency = 1.0
                                        flemms.pha[i,chan_index].filled[1] = 1
                                    ENDIF
                                ENDIF ELSE PRINT,'Failure to find pha geom chan_index '

                                    ;effic left this here but no effic in file FOR pha
                            ENDIF ELSE IF (purpose EQ purposes[5] AND $
								datatype EQ lemms_datatypes[1]) THEN BEGIN  
                                ;figure out which channel it is
                                chan_index = WHERE(lemms_pha_chans[*] EQ channel)

                                i = index
                                IF (chan_index[0] NE -1) THEN BEGIN
                                    IF flemms.pha[chan_index,i].filled[2] NE 1 THEN BEGIN
                                        lemms.pha[chan_index,i].efficiency = midpoint
                                        flemms.pha[chan_index,i].filled[2] = 1
                                    ENDIF
                                ENDIF
                            ENDIF ELSE IF (purpose EQ purposes[0] AND $
								datatype EQ lemms_datatypes[2]) THEN BEGIN   ;ENERGY fine rates
                                ;figure out which channel it is
                                chan_index = WHERE(lemmsacc_chararr[*] EQ channelindex)
                                part_index = WHERE(lemms_particles[*] EQ particle)
                                IF (chan_index[0] NE -1 AND part_index NE -1) THEN BEGIN   ;energy
                                    IF flemms.priority[part_index,chan_index].filled[0] NE 1 THEN BEGIN
                                        lemms.priority[part_index,chan_index].purpose = purpose
                                        lemms.priority[part_index,chan_index].datatype = datatype
                                        lemms.priority[part_index,chan_index].sensor = sensor
                                        lemms.priority[part_index,chan_index].channel = channel
                                        lemms.priority[part_index,chan_index].index = strindex
                                        lemms.priority[part_index,chan_index].particle = particle
                                        lemms.priority[part_index,chan_index].units = units
                                        lemms.priority[part_index,chan_index].low = low
                                        lemms.priority[part_index,chan_index].high = high
                                        lemms.priority[part_index,chan_index].delta = delta
                                        lemms.priority[part_index,chan_index].midpoint = midpoint
                                        lemms.priority[part_index,chan_index].source = source
                                        lemms.priority[part_index,chan_index].startutc = strstarttime
                                        lemms.priority[part_index,chan_index].stoputc = strstoptime
                                        flemms.priority[part_index,chan_index].filled[0] = 1
                                    ENDIF
								ENDIF ELSE PRINT,'Failure to locate lemms priority partindex and chan_index '
                            ENDIF ELSE IF (purpose EQ purposes[4] AND $
								datatype EQ lemms_datatypes[2]) THEN  BEGIN   ;geom factor
								
                                chan_index = WHERE(lemmsacc_chararr[*] EQ channelindex)
                                part_index = WHERE(lemms_particles[*] EQ particle)
                                IF (chan_index[0] NE -1 AND part_index NE -1) THEN BEGIN   ;energy
                                    IF flemms.priority[part_index,chan_index].filled[1] NE 1 THEN BEGIN
                                            lemms.priority[part_index,chan_index].geometry_factor = midpoint
                                            lemms.priority[part_index,chan_index].efficiency = 1.0;
                                            flemms.priority[part_index,chan_index].filled[1] = 1;
                                     ENDIF
								ENDIF ELSE PRINT,'Failure to locate lemms priority geometry partindex and chan_index '

                           ENDIF ELSE IF (purpose EQ purposes[5] AND $
								datatype EQ lemms_datatypes[2]) THEN BEGIN   ;effic
                                chan_index = WHERE(lemmsacc_chararr[*] EQ channelindex)
                                part_index = WHERE(lemms_particles[*] EQ particle)
                                IF (chan_index[0] NE -1 AND part_index NE -1) THEN BEGIN   ;energy
                                    IF flemms.priority[part_index,chan_index].filled[2] NE 1 THEN BEGIN
                                            lemms.priority[part_index,chan_index].efficiency = midpoint
                                            flemms.priority[part_index,chan_index].filled[2] = 1
                                    ENDIF
                                ENDIF ELSE PRINT,'Failure to locate lemms priority effic partindex and chan_index '

							ENDIF
			;;;;;;;;; CHEMS ;;;;;;;;;;;;;;;
                        ENDIF ELSE IF (sensor EQ chems_sensor) THEN BEGIN
                        
                            IF datatype EQ chems_datatypes[0] THEN BEGIN   ;science rates
                                IF purpose EQ purposes[1] THEN BEGIN       ;energy/charge
                                    IF channel EQ chems_channels[0] THEN BEGIN ;sci, load all dpps
                                        IF fchems.dpps_sci[index].filled[0] NE 1 THEN BEGIN
                                        chems.dpps_sci[index].purpose = purpose
                                        chems.dpps_sci[index].datatype = datatype
                                        chems.dpps_sci[index].sensor = sensor
                                        chems.dpps_sci[index].channel = channel
                                        chems.dpps_sci[index].index = strindex
                                        chems.dpps_sci[index].particle = particle
                                        chems.dpps_sci[index].units = units
                                        chems.dpps_sci[index].low = low
                                        chems.dpps_sci[index].high = high
                                        chems.dpps_sci[index].delta = delta
                                        chems.dpps_sci[index].midpoint = midpoint
                                        chems.dpps_sci[index].source = source
                                        chems.dpps_sci[index].startutc = strstarttime
                                        chems.dpps_sci[index].stoputc = strstoptime
                                        fchems.dpps_sci[index].filled[0] = 1
                                        ENDIF
                                    ENDIF
                                ENDIF ELSE IF purpose EQ purposes[2] THEN BEGIN  ;mass
                                    part_index = -1;
                                    for n=0,nchems_particles-1 DO BEGIN
                                        IF particle EQ chems_particletypes[n] AND $
                                                strindex EQ chems_indextypes[n] THEN BEGIN
                                            part_index = n;
                                        ENDIF
                                    ENDFOR
                                    
                                    IF part_index NE -1 THEN BEGIN
                                        IF fchems.mass[part_index].filled[0] NE 1 THEN BEGIN
                                        	chems.mass[part_index].purpose = purpose
                                        	chems.mass[part_index].datatype = datatype
                                        	chems.mass[part_index].sensor = sensor
                                        	chems.mass[part_index].channel = channel
                                        	chems.mass[part_index].index = strindex
                                        	chems.mass[part_index].particle = particle
                                        	chems.mass[part_index].units = units
                                        	chems.mass[part_index].low = low
                                        	chems.mass[part_index].high = high
                                        	chems.mass[part_index].delta = delta
                                        	chems.mass[part_index].midpoint = midpoint
                                        	chems.mass[part_index].source = source
                                        	chems.mass[part_index].startutc = strstarttime
                                        	chems.mass[part_index].stoputc = strstoptime
                                        	fchems.mass[part_index].filled[0] = 1

                                        	IF chems.mass[part_index].particle EQ chems_particles[3] THEN BEGIN
                                            	chems.mass[part_index-1].purpose = purpose
                                            	chems.mass[part_index-1].datatype = datatype
                                            	chems.mass[part_index-1].sensor = sensor
                                            	chems.mass[part_index-1].channel = channel
                                            	chems.mass[part_index-1].index = strindex
                                            	chems.mass[part_index-1].particle = particle
                                            	chems.mass[part_index-1].units = units
                                            	chems.mass[part_index-1].low = low
                                            	chems.mass[part_index-1].high = high
                                            	chems.mass[part_index-1].delta = delta
                                            	chems.mass[part_index-1].midpoint = midpoint
                                            	chems.mass[part_index-1].source = source
                                        		chems.mass[part_index-1].startutc = strstarttime
                                        		chems.mass[part_index-1].stoputc = strstoptime
                                            	fchems.mass[part_index-1].filled[0] = 1

                                            	chems.mass[part_index-2].purpose = purpose
                                            	chems.mass[part_index-2].datatype = datatype
                                            	chems.mass[part_index-2].sensor = sensor
                                            	chems.mass[part_index-2].channel = channel
                                            	chems.mass[part_index-2].index = strindex
                                            	chems.mass[part_index-2].particle = particle
                                            	chems.mass[part_index-2].units = units
                                            	chems.mass[part_index-2].low = low
                                            	chems.mass[part_index-2].high = high
                                            	chems.mass[part_index-2].delta = delta
                                            	chems.mass[part_index-2].midpoint = midpoint
                                            	chems.mass[part_index-2].source = source
                                        		chems.mass[part_index-2].startutc = strstarttime
                                        		chems.mass[part_index-2].stoputc = strstoptime
                                            	fchems.mass[part_index-2].filled[0] = 1
                                        	ENDIF
                                        ENDIF

                                    ENDIF
                                ENDIF  ELSE IF purpose EQ purposes[3] THEN BEGIN  ;mass/charge
                                    part_index = -1;
                                    for n=0,nchems_particles-1 DO BEGIN
                                        IF particle EQ chems_particletypes[n] AND $
                                                strindex EQ chems_indextypes[n] THEN BEGIN
                                            part_index = n;
                                        ENDIF
                                    ENDFOR
                                    IF part_index NE -1 THEN BEGIN
                                        IF fchems.mass_charge[part_index].filled[0] NE 1 THEN BEGIN
                                        	chems.mass_charge[part_index].purpose = purpose
                                        	chems.mass_charge[part_index].datatype = datatype
                                        	chems.mass_charge[part_index].sensor = sensor
                                        	chems.mass_charge[part_index].channel = channel
                                        	chems.mass_charge[part_index].index = strindex
                                        	chems.mass_charge[part_index].particle = particle
                                        	chems.mass_charge[part_index].units = units
                                        	chems.mass_charge[part_index].low = low
                                        	chems.mass_charge[part_index].high = high
                                        	chems.mass_charge[part_index].delta = delta
                                        	chems.mass_charge[part_index].midpoint = midpoint
                                        	chems.mass_charge[part_index].source = source
                                        	chems.mass_charge[part_index].startutc = strstarttime
                                        	chems.mass_charge[part_index].stoputc = strstoptime
                                        	fchems.mass_charge[part_index].filled[0] = 1

                                        	IF chems.mass[part_index].particle EQ chems_particles[3] THEN BEGIN
                                            	chems.mass_charge[part_index-1].purpose = purpose
                                            	chems.mass_charge[part_index-1].datatype = datatype
                                            	chems.mass_charge[part_index-1].sensor = sensor
                                            	chems.mass_charge[part_index-1].channel = channel
                                            	chems.mass_charge[part_index-1].index = strindex
                                            	chems.mass_charge[part_index-1].particle = particle
                                            	chems.mass_charge[part_index-1].units = units
                                            	chems.mass_charge[part_index-1].low = low
                                            	chems.mass_charge[part_index-1].high = high
                                            	chems.mass_charge[part_index-1].delta = delta
                                            	chems.mass_charge[part_index-1].midpoint = midpoint
                                            	chems.mass_charge[part_index-1].source = source
                                        		chems.mass_charge[part_index-1].startutc = strstarttime
                                        		chems.mass_charge[part_index-1].stoputc = strstoptime
                                            	fchems.mass_charge[part_index-1].filled[0] = 1

                                            	chems.mass_charge[part_index-2].purpose = purpose
                                            	chems.mass_charge[part_index-2].datatype = datatype
                                            	chems.mass_charge[part_index-2].sensor = sensor
                                            	chems.mass_charge[part_index-2].channel = channel
                                            	chems.mass_charge[part_index-2].index = strindex
                                            	chems.mass_charge[part_index-2].particle = particle
                                            	chems.mass_charge[part_index-2].units = units
                                            	chems.mass_charge[part_index-2].low = low
                                            	chems.mass_charge[part_index-2].high = high
                                            	chems.mass_charge[part_index-2].delta = delta
                                            	chems.mass_charge[part_index-2].midpoint = midpoint
                                            	chems.mass_charge[part_index-2].source = source
                                        		chems.mass_charge[part_index-2].startutc = strstarttime
                                        		chems.mass_charge[part_index-2].stoputc = strstoptime
                                            	fchems.mass_charge[part_index-2].filled[0] = 1
                                        	ENDIF  
                                    	ENDIF
                                    ENDIF
                                ENDIF  ELSE IF purpose EQ purposes[4] THEN BEGIN  ;geom
                                    IF fchems.telescope_gf[index].filled[0] NE 1 tHEN BEGIN
                                    chems.telescope_gf[index].purpose = purpose
                                    chems.telescope_gf[index].datatype = datatype
                                    chems.telescope_gf[index].sensor = sensor
                                    chems.telescope_gf[index].channel = channel
                                    chems.telescope_gf[index].index = strindex
                                    chems.telescope_gf[index].particle = particle
                                    chems.telescope_gf[index].units = units
                                    chems.telescope_gf[index].low = low
                                    chems.telescope_gf[index].high = high
                                    chems.telescope_gf[index].delta = delta
                                    chems.telescope_gf[index].midpoint = midpoint
                                    chems.telescope_gf[index].source = source
                                    chems.telescope_gf[index].startutc = strstarttime
                                    chems.telescope_gf[index].stoputc = strstoptime
                                    fchems.telescope_gf[index].filled[0] = 1
                                    ENDIF
                                ENDIF   ELSE IF purpose EQ purposes[5] THEN BEGIN  ;efficiency
                                    part_index = -1;
                                    for n=0,N_ELEMENTS(chems_particles)-1  DO BEGIN
                                        IF particle EQ chems_particles[n] THEN BEGIN
                                            part_index = n;
                                        ENDIF
                                    ENDFOR
									
                                    IF part_index NE -1 THEN BEGIN
										n_add = 0
										IF N_ELEMENTS(data) EQ 17 THEN BEGIN
											mye = STRSPLIT(data[16],' ',/EXTRACT)
											n_add = N_ELEMENTS(mye)
										ENDIF
                                    	IF fchems.dpps_sci_eff[index,part_index].filled[0] NE 1 tHEN BEGIN
                                        	chems.dpps_sci_eff[index,part_index].purpose = purpose
                                        	chems.dpps_sci_eff[index,part_index].datatype = datatype
                                        	chems.dpps_sci_eff[index,part_index].sensor = sensor
                                        	chems.dpps_sci_eff[index,part_index].channel = channel
                                        	chems.dpps_sci_eff[index,part_index].index = strindex
                                        	chems.dpps_sci_eff[index,part_index].particle = particle
                                        	chems.dpps_sci_eff[index,part_index].units = units
                                        	chems.dpps_sci_eff[index,part_index].low = low
                                        	chems.dpps_sci_eff[index,part_index].high = high
                                        	chems.dpps_sci_eff[index,part_index].delta = delta
                                        	chems.dpps_sci_eff[index,part_index].midpoint = midpoint
                                        	chems.dpps_sci_eff[index,part_index].efficiency = midpoint
                                        	chems.dpps_sci_eff[index,part_index].source = source
                                        	chems.dpps_sci_eff[index,part_index].startutc = strstarttime
                                        	chems.dpps_sci_eff[index,part_index].stoputc = strstoptime
											chems.dpps_sci_eff[index,part_index].adnl_part=STRJOIN(mye[*],' ')
                                        	fchems.dpps_sci_eff[index,part_index].filled[0] = 1
                                    	ENDIF
                                    ENDIF
                                ENDIF  ELSE IF purpose EQ purposes[6] THEN BEGIN  ;fov
                                    IF fchems.telescope_fov.filled[0] NE 1 tHEN BEGIN
                                    chems.telescope_fov.purpose = purpose
                                    chems.telescope_fov.datatype = datatype
                                    chems.telescope_fov.sensor = sensor
                                    chems.telescope_fov.channel = channel
                                    chems.telescope_fov.index = strindex
                                    chems.telescope_fov.particle = particle
                                    chems.telescope_fov.units = units
                                    chems.telescope_fov.low = low
                                    chems.telescope_fov.high = high
                                    chems.telescope_fov.delta = delta
                                    chems.telescope_fov.midpoint = midpoint
                                    chems.telescope_fov.source = source
                                    chems.telescope_fov.startutc = strstarttime
                                    chems.telescope_fov.stoputc = strstoptime
                                    fchems.telescope_fov.filled[0] = 1
                                ENDIF
                                ENDIF
                            ENDIF ELSE IF datatype EQ chems_datatypes[1] THEN BEGIN   ;pha

                                IF purpose EQ purposes[1] THEN BEGIN
                                    IF fchems.dpps_pha[index].filled[0] NE 1 tHEN BEGIN
                                    chems.dpps_pha[index].purpose = purpose
                                    chems.dpps_pha[index].datatype = datatype
                                    chems.dpps_pha[index].sensor = sensor
                                    chems.dpps_pha[index].channel = channel
                                    chems.dpps_pha[index].index = strindex
                                    chems.dpps_pha[index].particle = particle
                                    chems.dpps_pha[index].units = units
                                    chems.dpps_pha[index].low = low
                                    chems.dpps_pha[index].high = high
                                    chems.dpps_pha[index].delta = delta
                                    chems.dpps_pha[index].midpoint = midpoint
                                    chems.dpps_pha[index].source = source
                                    chems.dpps_pha[index].startutc = strstarttime
                                    chems.dpps_pha[index].stoputc = strstoptime
                                    fchems.dpps_pha[index].filled[0] = 1
                                ENDIF
                                ENDIF

                            ENDIF   ;datatype
                ;;;;;;;;;;INCA Sensor;;;;;;;;;;;;;
                        ENDIF ELSE IF (sensor EQ inca_sensor) THEN BEGIN
						    IF purpose EQ purposes[0] THEN BEGIN    ;Energy
                                IF channel EQ inca_channels[0] THEN BEGIN   ;neu-tof
								    pp = WHERE(particle EQ inca_species)
                                    IF pp[0] NE -1 THEN BEGIN
										IF finca.image.tof[index,pp,0].filled[0] NE 1 tHEN BEGIN
                                        	inca.image.tof[index,pp,0].purpose = purpose
                                        	inca.image.tof[index,pp,0].datatype = datatype
                                        	inca.image.tof[index,pp,0].sensor = sensor
                                        	inca.image.tof[index,pp,0].channel = channel
                                        	inca.image.tof[index,pp,0].index = strindex
                                        	inca.image.tof[index,pp,0].particle = particle
                                        	inca.image.tof[index,pp,0].units = units
                                        	inca.image.tof[index,pp,0].low = low
                                        	inca.image.tof[index,pp,0].high = high
                                        	inca.image.tof[index,pp,0].delta = delta
                                        	inca.image.tof[index,pp,0].midpoint = midpoint
                                        	inca.image.tof[index,pp,0].source = source
                                        	inca.image.tof[index,pp,0].startutc = strstarttime
                                        	inca.image.tof[index,pp,0].stoputc = strstoptime
                                        	finca.image.tof[index,pp,0].filled[0] = 1
                                    	ENDIF
                                    ENDIF ELSE PRINT,'Failure in neu-tof to find pp',pp
									
                                ENDIF ELSE IF channel EQ inca_channels[1] THEN BEGIN   ;ion-tof
                                    pp = WHERE(particle EQ inca_species)
                                    IF pp[0] NE -1 THEN BEGIN
										IF finca.image.tof[index,pp,1].filled[0] NE 1 tHEN BEGIN
                                        	inca.image.tof[index,pp,1].purpose = purpose
                                        	inca.image.tof[index,pp,1].datatype = datatype
                                        	inca.image.tof[index,pp,1].sensor = sensor
                                        	inca.image.tof[index,pp,1].channel = channel
                                        	inca.image.tof[index,pp,1].index = strindex
                                        	inca.image.tof[index,pp,1].particle = particle
                                        	inca.image.tof[index,pp,1].units = units
                                        	inca.image.tof[index,pp,1].low = low
                                        	inca.image.tof[index,pp,1].high = high
                                        	inca.image.tof[index,pp,1].delta = delta
                                        	inca.image.tof[index,pp,1].midpoint = midpoint
                                        	inca.image.tof[index,pp,1].source = source
                                        	inca.image.tof[index,pp,1].startutc = strstarttime
                                        	inca.image.tof[index,pp,1].stoputc = strstoptime
                                        	finca.image.tof[index,pp,1].filled[0] = 1
                                    	ENDIF
                                    ENDIF ELSE PRINT,'Failure in ion-tof to find pp'
									
                                ENDIF ELSE IF channel EQ inca_channels[2] THEN BEGIN   ;spatial-tof
                                    pp = WHERE(particle EQ inca_species)
                                    ii = WHERE(index EQ inca_spat_tof)
                                    IF pp[0] NE -1 AND ii NE -1 THEN BEGIN
										IF finca.image.spatial[ii,pp].filled[0] NE 1 tHEN BEGIN
                                        	inca.image.spatial[ii,pp].purpose = purpose
                                        	inca.image.spatial[ii,pp].datatype = datatype
                                        	inca.image.spatial[ii,pp].sensor = sensor
                                        	inca.image.spatial[ii,pp].channel = channel
                                        	inca.image.spatial[ii,pp].index = strindex
                                        	inca.image.spatial[ii,pp].particle = particle
                                        	inca.image.spatial[ii,pp].units = units
                                        	inca.image.spatial[ii,pp].low = low
                                        	inca.image.spatial[ii,pp].high = high
                                        	inca.image.spatial[ii,pp].delta = delta
                                        	inca.image.spatial[ii,pp].midpoint = midpoint
                                        	inca.image.spatial[ii,pp].source = source
                                        	inca.image.spatial[ii,pp].startutc = strstarttime
                                        	inca.image.spatial[ii,pp].stoputc = strstoptime
                                        	finca.image.spatial[ii,pp].filled[0] = 1
                                    	ENDIF
                                    ENDIF ELSE PRINT,'Failure in spatial to find pp'
									
                                ENDIF ELSE IF channel EQ inca_channels[3] THEN BEGIN   ;time-tof
                                    pp = WHERE(particle EQ inca_charges)
                                    ii = WHERE(index EQ inca_spat_tof)
                                    IF pp[0] NE -1 AND ii NE -1 THEN BEGIN
										IF finca.image.time[ii,pp].filled[0] NE 1 tHEN BEGIN
                                        	inca.image.time[ii,pp].purpose = purpose
                                        	inca.image.time[ii,pp].datatype = datatype
                                        	inca.image.time[ii,pp].sensor = sensor
                                        	inca.image.time[ii,pp].channel = channel
                                        	inca.image.time[ii,pp].index = strindex
                                        	inca.image.time[ii,pp].particle = particle
                                        	inca.image.time[ii,pp].units = units
                                        	inca.image.time[ii,pp].low = low
                                        	inca.image.time[ii,pp].high = high
                                        	inca.image.time[ii,pp].delta = delta
                                        	inca.image.time[ii,pp].midpoint = midpoint
                                        	inca.image.time[ii,pp].source = source
                                        	inca.image.time[ii,pp].startutc = strstarttime
                                        	inca.image.time[ii,pp].stoputc = strstoptime
                                        	finca.image.time[ii,pp].filled[0] = 1
                                    	ENDIF
                                    ENDIF ELSE PRINT,'Failure in inca time to find pp or ii'
                                ENDIF
								
                            ENDIF ELSE IF purpose EQ purposes[4] THEN BEGIN ;geom_factor
								ii = -1
								pp = -1
                                IF datatype EQ inca_datatypes[1] THEN BEGIN  ;ACC
                                    ii = 0
                                    IF particle EQ inca_particles[0] THEN BEGIN
                                        pp = 0
                                    ENDIF ELSE BEGIn
                                        pp = 1
                                    ENDELSE
                                ENDIF ELSE IF datatype EQ inca_datatypes[2] THEN BEGIN   ;pha
                                    ii = 1
                                    pp = 0
                                ENDIF
                                
								IF pp[0] NE -1 AND ii NE -1 THEN BEGIN
                            
									IF finca.geometry[ii,pp].filled[0] NE 1 tHEN BEGIN
                                    	inca.geometry[ii,pp].purpose = purpose
                                    	inca.geometry[ii,pp].datatype = datatype
                                    	inca.geometry[ii,pp].sensor = sensor
                                    	inca.geometry[ii,pp].channel = channel
                                    	inca.geometry[ii,pp].index = strindex
                                    	inca.geometry[ii,pp].particle = particle
                                    	inca.geometry[ii,pp].units = units
                                    	inca.geometry[ii,pp].low = low
                                    	inca.geometry[ii,pp].high = high
                                    	inca.geometry[ii,pp].delta = delta
                                    	inca.geometry[ii,pp].midpoint = midpoint
                                    	inca.geometry[ii,pp].source = source
                                    	inca.geometry[ii,pp].startutc = strstarttime
                                    	inca.geometry[ii,pp].stoputc = strstoptime
                                    	finca.geometry[ii,pp].filled[0] = 1
                                	ENDIF
								ENDIF ELSE PRINT,'Failure in inca geometry to find pp or ii'
								
                            ENDIF ELSE IF purpose EQ purposes[7] THEN BEGIN ;e/nuc_b
							    IF finca.enuc_b.filled[0] NE 1 tHEN BEGIN
                                    inca.enuc_b.purpose = purpose
                                    inca.enuc_b.datatype = datatype
                                    inca.enuc_b.sensor = sensor
                                    inca.enuc_b.channel = channel
                                    inca.enuc_b.index = strindex
                                    inca.enuc_b.particle = particle
                                    inca.enuc_b.units = units
                                    inca.enuc_b.low = low
                                    inca.enuc_b.high = high
                                    inca.enuc_b.delta = delta
                                    inca.enuc_b.midpoint = midpoint
                                    inca.enuc_b.source = source
                                    inca.enuc_b.startutc = strstarttime
                                    inca.enuc_b.stoputc = strstoptime
                                    finca.enuc_b.filled[0] = 1
                                ENDIF
								
                            ENDIF ELSE IF purpose EQ purposes[8] THEN BEGIN ;background
                                IF channel EQ inca_channels[0] THEN BEGIN   ;neu-tof
                                    pp = WHERE(particle EQ inca_species)
                                    IF pp[0] NE -1 THEN BEGIN
										IF finca.background.tof[index,pp,0].filled[0] NE 1 tHEN BEGIN
                                        	inca.background.tof[index,pp,0].purpose = purpose
                                        	inca.background.tof[index,pp,0].datatype = datatype
                                        	inca.background.tof[index,pp,0].sensor = sensor
                                        	inca.background.tof[index,pp,0].channel = channel
                                        	inca.background.tof[index,pp,0].index = strindex
                                        	inca.background.tof[index,pp,0].particle = particle
                                        	inca.background.tof[index,pp,0].units = units
                                        	inca.background.tof[index,pp,0].low = low
                                        	inca.background.tof[index,pp,0].high = high
                                        	inca.background.tof[index,pp,0].delta = delta
                                        	inca.background.tof[index,pp,0].midpoint = midpoint
                                        	inca.background.tof[index,pp,0].source = source
                                        	inca.background.tof[index,pp,0].startutc = strstarttime
                                        	inca.background.tof[index,pp,0].stoputc = strstoptime
                                        	finca.background.tof[index,pp,0].filled[0] = 1
                                    	ENDIF
                                    ENDIF ELSE PRINT,'Failure in background neu-tof to find pp'
									
                                ENDIF ELSE IF channel EQ inca_channels[1] THEN BEGIN   ;ion-tof
                                    pp = WHERE(particle EQ inca_species)
                                    IF pp[0] NE -1 THEN BEGIN
										IF finca.background.tof[index,pp,1].filled[0] NE 1 tHEN BEGIN
                                        	inca.background.tof[index,pp,1].purpose = purpose
                                        	inca.background.tof[index,pp,1].datatype = datatype
                                        	inca.background.tof[index,pp,1].sensor = sensor
                                        	inca.background.tof[index,pp,1].channel = channel
                                        	inca.background.tof[index,pp,1].index = strindex
                                        	inca.background.tof[index,pp,1].particle = particle
                                        	inca.background.tof[index,pp,1].units = units
                                        	inca.background.tof[index,pp,1].low = low
                                        	inca.background.tof[index,pp,1].high = high
                                        	inca.background.tof[index,pp,1].delta = delta
                                        	inca.background.tof[index,pp,1].midpoint = midpoint
                                        	inca.background.tof[index,pp,1].source = source
                                        	inca.background.tof[index,pp,1].startutc = strstarttime
                                        	inca.background.tof[index,pp,1].stoputc = strstoptime
                                        	finca.background.tof[index,pp,1].filled[0] = 1
                                    	ENDIF
                                    ENDIF ELSE PRINT,'Failure in  background ion-tof to find pp'
									
                                ENDIF ELSE IF channel EQ inca_channels[2] THEN BEGIN   ;spatial-tof
                                    pp = WHERE(particle EQ inca_species)
                                    ii = WHERE(index EQ inca_spat_tof)
                                    IF pp[0] NE -1 AND ii NE -1 THEN BEGIN
										IF finca.background.spatial[ii,pp].filled[0] NE 1 tHEN BEGIN
                                        	inca.background.spatial[ii,pp].purpose = purpose
                                        	inca.background.spatial[ii,pp].datatype = datatype
                                        	inca.background.spatial[ii,pp].sensor = sensor
                                        	inca.background.spatial[ii,pp].channel = channel
                                        	inca.background.spatial[ii,pp].index = strindex
                                        	inca.background.spatial[ii,pp].particle = particle
                                        	inca.background.spatial[ii,pp].units = units
                                        	inca.background.spatial[ii,pp].low = low
                                        	inca.background.spatial[ii,pp].high = high
                                        	inca.background.spatial[ii,pp].delta = delta
                                        	inca.background.spatial[ii,pp].midpoint = midpoint
                                        	inca.background.spatial[ii,pp].source = source
                                        	inca.background.spatial[ii,pp].startutc = strstarttime
                                        	inca.background.spatial[ii,pp].stoputc = strstoptime
                                        	finca.background.spatial[ii,pp].filled[0] = 1
                                    	ENDIF
                                    ENDIF ELSE PRINT,'Failure in spatial background to find pp'
									
                                ENDIF ELSE IF channel EQ inca_channels[3] THEN BEGIN   ;time-tof
                                    pp = WHERE(particle EQ inca_charges)
                                    ii = WHERE(index EQ inca_spat_tof)
                                    IF pp[0] NE -1 AND ii NE -1 THEN BEGIN
										IF finca.background.time[ii,pp].filled[0] NE 1 tHEN BEGIN
                                        	inca.background.time[ii,pp].purpose = purpose
                                        	inca.background.time[ii,pp].datatype = datatype
                                        	inca.background.time[ii,pp].sensor = sensor
                                        	inca.background.time[ii,pp].channel = channel
                                        	inca.background.time[ii,pp].index = strindex
                                        	inca.background.time[ii,pp].particle = particle
                                        	inca.background.time[ii,pp].units = units
                                        	inca.background.time[ii,pp].low = low
                                        	inca.background.time[ii,pp].high = high
                                        	inca.background.time[ii,pp].delta = delta
                                        	inca.background.time[ii,pp].midpoint = midpoint
                                        	inca.background.time[ii,pp].source = source
                                        	inca.background.time[ii,pp].startutc = strstarttime
                                        	inca.background.time[ii,pp].stoputc = strstoptime
                                        	finca.background.time[ii,pp].filled[0] = 1
                                    	ENDIF
                                    ENDIF  ELSE PRINT,'Failure in inca time background to find pp'
                                ENDIF
                            ENDIF
                        
                        ENDIF   ;chems or lemms sensor

                    ENDIF;et test
                    
                ENDIF ;year = 0 test

            ENDIF   ;not empty string

        ENDWHILE    ;read
        CLOSE,lun
        FREE_LUN,lun
    

        ;determine maximum calibration level 0-counts, 1-counts/sec, 2-integral intensity, 3-dIFferential intensity
        ; integral intensity requires geometry, efficiency 
        ; dIFferential intensity requires geometry, efficiency and delta or low and high

        ;max_calib_level; 
        FOR n=0,MAX_LEMMS_NORMAL_CNTRS-1 DO BEGIN
            FOR k=0,LEMMS_NUM_PARTICLES-1 DO BEGIN
                lemms.normal[k,n].max_calib_level = 1 
                
                IF lemms.normal[k,n].geometry_factor NE 0.0 AND $
                    lemms.normal[k,n].efficiency NE 0.0 AND $
                    flemms.normal[k,n].filled[0] NE 0 THEN BEGIN
                    
                    lemms.normal[k,n].max_calib_level = 2
                    
                    IF lemms.normal[k,n].low NE 0.0 && $
                    lemms.normal[k,n].high NE 0.0 && $
                     lemms.normal[k,n].midpoint NE 0.0  THEN BEGIN
                        lemms.normal[k,n].max_calib_level = 3
                    ENDIF
                ENDIF  
            ENDFOR
        ENDFOR
        FOR n=0,MAX_LEMMS_NORMAL_CNTRS-1 DO BEGIN
            FOR k=0,LEMMS_NUM_PARTICLES-1 DO BEGIN
                lemms.priority[k,n].max_calib_level = 1; 
                IF lemms.priority[k,n].geometry_factor NE 0.0 AND $
                    lemms.priority[k,n].efficiency NE 0.0 AND $
                    flemms.priority[k,n].filled[0] NE 0  THEN BEGIN
                
                    lemms.priority[k,n].max_calib_level = 2
                    
                    IF lemms.priority[k,n].low NE 0.0 && $
                    lemms.priority[k,n].high NE 0.0 && $
                    lemms.priority[k,n].midpoint NE 0.0 THEN BEGIN
                        lemms.priority[k,n].max_calib_level = 3
                    ENDIF
                ENDIF  
            ENDFOR
        ENDFOR
        FOR k=0,MAX_LEMMSPHA_DET-1 DO BEGIN
            FOR n=0,MAX_LEMMSPHA_NORM+MAX_LEMMSPHA_PRIO-1 DO BEGIN
                lemms.pha[n,k].max_calib_level = 1
                IF lemms.pha[n,k].geometry_factor NE 0.0 AND $
                    lemms.pha[n,k].efficiency NE 0.0 AND $
                    flemms.pha[n,k].filled[0] NE 0 THEN BEGIN
                
                    lemms.pha[n,k].max_calib_level = 2
                    
                    IF (lemms.pha[n,k].low NE 0.0 && $
                    lemms.pha[n,k].high NE 0.0 && $
                    lemms.pha[n,k].midpoint NE 0.0) THEN BEGIN
                        lemms.pha[n,k].max_calib_level = 3
                    ENDIF
                ENDIF
            ENDFOR
        ENDFOR
    ENDELSE 
	
RETURN,status
END

