;+
; NAME:
;	PDS_READ_OUTOFCAL
;
; PURPOSE:
;	Reads the inca high voltage out of calibration files
;   
; NOTE: 
;
; CATEGORY:
;	Plotting Structure File. 
;
; CALLING SEQUENCE:
;	struct = READ_OUTOFCAL(starttime, stoptime, data, calstatus)
;
; NOTE:
;	This routine depends on the environmental variable OUTOFCAL_DIR being set to the 
;	directory of the  MIMI INCA High Voltage Out of Calibration files. This is done in
;	the setup.pro routine. The user should edit the setup file to point to their paths.
;	See MIMI website for files
;					http://cassini-mimi.jhuapl.edu/data_auxiliary.html
; INPUTS:
;	starttime, stoptime		UTC string times yyyy-doyThh:mm:sec.msc Times to search for out of calibration
;	data		Out of calibration srray of structures {startutc:'',startet:0d,stoputc:'',stopet:0d,flag:0l}	
;	calstatus	0: found data, -1 didn't find any out of calibration data for that time period
;
; KEYWORD PARAMETERS:
;
;
;                       Copyright (C) 2008
; The Johns Hopkins University Applied Physics Laboratory (JHU/APL)
;                       All rights reserved
;
; This material may be used, modified or reproduced by or for the
; U.S. Government pursuant to the license rights granted under
; the clauses at DFARS 252.227-7013/7014.
;
; CREATION:
;       23 Apr 2010, M.B. Kusterer 
;
; MODIFICATION HISTORY: 
;-
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
PRO TEST_ROUT

starttime = '2009-001T00:00'
stoptime = '2010-020T23:59:59.999'
s=PDS_READ_OUTOFCAL(starttime, stoptime,GETENV('OUTOFCAL_DIR'), data, cs)
print,'s ',s
print,'cs ',cs
if s NE -1 AND cs NE -1 THEN print,data

RETURN
END

FUNCTION PDS_READ_OUTOFCAL, starttime, stoptime, dir, data, calstatus

	status = 0
    calstatus = -1
	IF FILE_TEST(dir,/DIRECTORY) NE 1 THEN BEGIN
		PRINT,'PDS_READ_OUTOFCAL: Failure to find directory '+dir
		data=0
		calstatus = 0
		RETURN,-1
	ENDIF
	
	;figure out years
	TIMESTR2NUM, starttime, startyear, startdoy, starthours, startmins, startsecs
	TIMESTR2NUM, stoptime, stopyear, stopdoy, stophours, stopmins, stopsecs
	years = startyear
	stryears = STRCOMPRESS(STRING(startyear),/REMOVE_ALL)
	IF startyear NE stopyear THEN BEGIN
		for y=startyear[0]+1,stopyear[0] DO BEGIN
			years = [years,y]
			stryears = [stryears,STRCOMPRESS(STRING(y),/REMOVE_ALL)]
		ENDFOR
	ENDIF

	files = dir+'incahv_outofcal_'+stryears+'.txt'

	incahv_cal = {startutc:'',startet:0d,stoputc:'',stopet:0d,flag:0l}
	
	s=UTC2ET([starttime,stoptime],et)
	
    
	FOR n=0,N_ELEMENTS(files)-1 DO BEGIN
		OPENR,lun,files[n],/GET_LUN, ERROR = status
    	IF (status lt 0) then begin
        	MESSAGE,/CONT,'Can not read from ' + files[n]
    	ENDIF ELSE BEGIN

    	buff = ''
        
        READF,lun,buff	;read titles
    	WHILE (NOT EOF(lun)) DO BEGIN
        	READF,lun,buff
        	e = STRSPLIT(buff,',',/EXTRACT) ;split out data into fields
        	IF N_ELEMENTS(e) EQ 5 AND $
            (DOUBLE(e[3]) GE et[0] AND DOUBLE(e[1]) LE et[1]) THEN BEGIN
				incahv_cal.startutc = e[0]
				incahv_cal.startet = DOUBLE(e[1])
				incahv_cal.stoputc = e[2]
				incahv_cal.stopet = DOUBLE(e[3])
				incahv_cal.flag = LONG(e[4])
				
            	data = (N_ELEMENTS(data) EQ 0) ? incahv_cal : [data,incahv_cal]
                calstatus = 0
        	ENDIF
    	ENDWHILE  
		CLOSE,lun 
    	FREE_LUN,lun
		ENDELSE
	ENDFOR
	
RETURN,status
END
