;
;    Program Name:              stat = pds_set_label_envvar.cpp
;   
;    Description:    This routine sets the environmental variables based on a file containing
;                   the files and the time of activation on the instrument.
;   
;   
;    Parameters:
;       start_et    double ET of start of processing file
;   
;                       Copyright (C) 2011
; The Johns Hopkins University Applied Physics Laboratory (JHU/APL)
;                       All rights reserved
;
; This material may be used, modified or reproduced by or FOR the
; U.S. Government pursuant to the license rights granted under
; the clauses at DFARS 252.227-7013/7014.
;
;    Change History:
;   
;    Date          Rev     Programmer      Comments
;    ----          ---     ----------      --------
; 13 June 2000    M.B. Kusterer Original
; 2 Oct 2001    M.B. Kusterer  Changed place to get labels to decom/config
;  17 Nov 2002, M.B. Kusterer  Replaced SCETSCLK with SPICE_UTC2ET which uses SPICe/IDL DLM
;  22 July 2008, M.B.Kusterer Removed execute. 
;  17 Feb 2009    M.B. Kusterer No change but added new lemms priority channels 1 was A0 now C3, 2009-050
;                               5 was P2, now E0. Changed decom_labels2.txt to add decom_lemmsacc_conv7.txt
;                               and decom_lemmsacc_labels7.txt
;  02 June 2011, M.B.Kusterer Added PDS_ to name, change spice_et2utc,spice_utc2et to non-spice
;       and changed path from DECOM_CONFIG to IDL_DIR.
; 

FUNCTION PDS_SET_LABEL_ENVVAR, start_et,$
            DECOM_SWVER_FILE,SCIRECHDR_FILENAME,DATAHDR_FILENAME,$
            EXTRAHDR_FILENAME,LEMMSACC_FILENAME,LEMMSPHA_FILENAME,INCAACC_FILENAME,INCAPHA_FILENAME,$
            INCARAW_FILENAME,INCAIMAGE_FILENAME, MIMI_RF_FILE,CHEMSACC_FILENAME,CHEMSPHA_FILENAME,$
            CHEMSRATE_FILENAME,CHEMSRAW_FILENAME,AUX_FILENAME,HSKPANALOGDIG_FILENAME,$
            HSKPSUBCOM_FILENAME,HSKPCMD_FILENAME,MIMI_COMMANDTEXT_FILENAME,$
            MAG_FILENAME,MROHDR_FILENAME,MRODATA_FILENAME,SFDU_FILENAME, CHEMSRATEFLUX_FILENAME
       
    ;change from version 34 to version 35        
    ;result = SPICE_UTC2ET('2003-255T00:00:00.000', changeet)
     
     ;WILL NEED TO CHANGE THIS WHEN REPLACE ALL VERSION 34 files
     
            
        path = getenv('IDL_DIR')+"decom_labels2.txt"
    error_status = 0
    
    totals = 0
    numfiles = 0
    OPENR,inf,path,/GET_LUN, ERROR = error_status
    if (error_status NE -1) THEN BEGIN
        READF,inf,totals
        FOR i=0,totals-1 DO BEGIN
            READF,inf,numfiles
            if (numfiles EQ 1) THEN BEGIN
                bigtext = ''
                READF,inf,bigtext
                filelist = STRSPLIT(bigtext,' ',/EXTRACT)
                thefile = filelist[0]
                scet = filelist[1]
            ENDIF ELSE BEGIN
                FOR j=0,numfiles-1 DO BEGIN
                     bigtext = ''
                    READF,inf,bigtext
                    filelist = STRSPLIT(bigtext,' ',/EXTRACT)
                    file = filelist[0]
                    scet = filelist[1]
                    ;result = SCETSCLK(sc, 1, scet, sclksecs, sclkfine, errst, et, part_num)
                    result = UTC2ET(scet, et)
                    IF (start_et[0] GT et[0]) THEN thefile = file[0]
                ENDFOR
            ENDELSE         
             
            IF (i EQ 0) THEN DECOM_SWVER_FILE = thefile $
            ELSE IF (i EQ 1) THEN SCIRECHDR_FILENAME = thefile $
            ELSE IF (i EQ 2) THEN DATAHDR_FILENAME = thefile $
            ELSE IF (i EQ 3) THEN EXTRAHDR_FILENAME = thefile $
            ELSE IF (i EQ 4) THEN LEMMSACC_FILENAME = thefile $
            ELSE IF (i EQ 5) THEN LEMMSPHA_FILENAME = thefile $
            ELSE IF (i EQ 6) THEN INCAACC_FILENAME = thefile $
            ELSE IF (i EQ 7) THEN INCAPHA_FILENAME = thefile $
            ELSE IF (i EQ 8) THEN INCARAW_FILENAME = thefile $
            ELSE IF (i EQ 9) THEN INCAIMAGE_FILENAME = thefile $
            ELSE IF (i EQ 10) THEN MIMI_RF_FILE = thefile $
            ELSE IF (i EQ 11) THEN CHEMSACC_FILENAME = thefile $
            ELSE IF (i EQ 12) THEN CHEMSPHA_FILENAME = thefile $
            ELSE IF (i EQ 13) THEN CHEMSRATE_FILENAME = thefile $
            ELSE IF (i EQ 14) THEN CHEMSRAW_FILENAME = thefile $
            ELSE IF (i EQ 15) THEN  AUX_FILENAME = thefile $
            ELSE IF (i EQ 16) THEN  HSKPANALOGDIG_FILENAME = thefile $
            ELSE IF (i EQ 17) THEN  HSKPSUBCOM_FILENAME = thefile $
            ELSE IF (i EQ 18) THEN  HSKPCMD_FILENAME = thefile $
            ELSE IF (i EQ 19) THEN  MIMI_COMMANDTEXT_FILENAME = thefile $
            ELSE IF (i EQ 20) THEN  MAG_FILENAME = thefile $
            ELSE IF (i EQ 21) THEN MROHDR_FILENAME = thefile $
            ELSE IF (i EQ 22) THEN MRODATA_FILENAME = thefile $
            ELSE IF (i EQ 23) THEN SFDU_FILENAME = thefile $
			ELSE IF (i EQ 24) THEN SC_QUAT_FILENAME = thefile $
			ELSE IF (i EQ 25) THEN MAG_CONV_R0_OFFSET_FILENAME = thefile $
			ELSE IF (i EQ 26) THEN MAG_CONV_R1_OFFSET_FILENAME = thefile $
			ELSE IF (i EQ 27) THEN MAG_CONV_R2_OFFSET_FILENAME = thefile $
			ELSE IF (i EQ 28) THEN MAG_CONV_R3_OFFSET_FILENAME = thefile $
			ELSE IF (i EQ 29) THEN MAG_CONV_ORTHO_FILENAME = thefile $
			ELSE IF (i EQ 30) THEN MAG_CONV_FSD_FILENAME = thefile $
			ELSE IF (i EQ 31) THEN LEMMS_CHEMS_CALIB_FILENAME = thefile $
			ELSE IF (i EQ 32) THEN LEMMS_CONVERT_FILENAME = thefile $
			ELSE IF (i EQ 33) THEN INCAAVE_FILENAME = thefile $
			ELSE IF (i EQ 34) THEN CHEMSRATEFLUX_FILENAME = thefile


        ENDFOR
        CLOSE,inf
        FREE_LUN,inf
    ENDIF ELSE BEGIN 
        PRINT,"Error reading from " + path
        return,-1
    ENDELSE
    return,0

END
    
