;+
; NAME:
;	PDS_XFORM_VECTOR
;
; PURPOSE:
;	Program transforms a vector from one SPICE reference frame to another, 
;	but deals with one of the frames not being inertial.
;   
; NOTE: 
;
; CATEGORY:
;	Plotting Structure File. 
;
; CALLING SEQUENCE:
;	PDS_XFORM_VECTOR, fromframe, fromet, toframe, toet, vector
;
; INPUTS:
;	fromframe	SPICE reference frame transforming from
;	fromet		Ephemeris time transforming from
;	toframe		SPICE reference frame transforming to
;	toet		Ephemeris time transforming to
;	vector		vector in original SPICE reference frame
;	
; RETURNS:
;	vector_to	Vector transformed into toframe frame.
;	
; KEYWORD PARAMETERS:
;
;
;                       Copyright (C) 2009
; The Johns Hopkins University Applied Physics Laboratory (JHU/APL)
;                       All rights reserved
;
; This material may be used, modified or reproduced by or for the
; U.S. Government pursuant to the license rights granted under
; the clauses at DFARS 252.227-7013/7014.
;
; CREATION:
;      03 August 2012, M.B. Kusterer 
;
; MODIFICATION HISTORY: 
;-
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
FUNCTION PDS_XFORM_VECTOR, fromframe, fromet, toframe, toet, vector_from, $
	status = status
    
    status = 0
	
	CATCH, error
    IF error NE 0 THEN BEGIN
        PRINT,'XFORM_VECTOR: Error'
        RETURN,-1
    ENDIF
	
    ;get matrix to transform from J2000 to toframe
	CSPICE_PXFORM, 'J2000', toframe ,  toet, rotate_J20002toframe
    
	;get matrix to transform from fromframe to J2000
	;We use the J2000 frame in the middle to deal with one of the frames
	;not being intertial.
    CSPICE_PXFORM,  fromframe,'J2000', fromet, rotate_fromframe2J2000
	
	;calculate the product of two 3x3 matrices, this will give us the 
	;matrix to transform the vector from the original frame to the J2000
	;frame and on to the desired frame.
    CSPICE_MXM, rotate_J20002toframe, rotate_fromframe2J2000, rotate_from2to 
    
	;find the product of the 3x3 matrix and the 3-vector. This will give 
	;us the vector in the desired frame.
    CSPICE_MXV, rotate_from2to, vector_from[0:2], vector_to 

RETURN, vector_to
END
