;+
; NAME:
;	READ_NEUIONMODES
;
; PURPOSE:
;	Read INCA Ion/Neutral mode files. 
;   
; NOTE: 
;
; CATEGORY:
;	Plotting Support File. 
;
; CALLING SEQUENCE:
;	status = READ_NEUIONMODES(startime, stoptime, data)
;
; INPUTS:
;	starttime	UTC string starttime to read
;	sotptime 	UTC string stoptime to read in
;
;
; KEYWORD PARAMETERS:
;	
;
;
;
;                       Copyright (C) 2012
; The Johns Hopkins University Applied Physics Laboratory (JHU/APL)
;                       All rights reserved
;
; This material may be used, modified or reproduced by or for the
; U.S. Government pursuant to the license rights granted under
; the clauses at DFARS 252.227-7013/7014.
;
; CREATION:
;       11 June 2012, M.B. Kusterer 
;
; MODIFICATION HISTORY: 
;-
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
PRO TEST_RNIM
	startime = '2011-001T00:00:00'
	stoptime = '2011-010T00:00:00'
	print,READ_NEUIONMODES(startime, stoptime, data)
	for n=0,n_elements(data.mode)-1 do print,data.utc[*,n],' ',data.mode[n]
RETURN
END

FUNCTION READ_NEUIONMODES, starttime, stoptime, mydata

	status = 0
	p = PATH_SEP()
	
	startyear = LONG(STRMID(starttime,0,4))
	stopyear = LONG(STRMID(stoptime,0,4))
	years = STRCOMPRESS(STRING(startyear + LINDGEN(stopyear-startyear+1)),/REMOVE_ALL)
	s=UTC2ET([starttime,stoptime],et)
	
	modedir = 'INCA_ionneutral_times'
	filestub = 'MIMI_INCA_NeutralIon'
	files = GETENV('NEUION_DIR')+filestub+years+'.txt'
	print,files
	nlines = FILE_LINES(files)
	tnlines = TOTAL(nlines)
	IF tnlines EQ 0 THEN BEGIN
		PRINT,'READ_INCAMODES: Failure to find matching data for '+filestub
		RETURN,-1
	ENDIF
	
	tnlines -= N_ELEMENTS(files)	;correct for title lines
	IF tnlines EQ 0 THEN BEGIN
		PRINT,'READ_INCAMODES: Failure to find matching data for '+filestub
		RETURN,-1
	ENDIF
	data = {utc:STRARR(2,tnlines),et:DBLARR(2,tnlines),mode:LONARR(tnlines)}
	keep = LONARR(tnlines)
	keep[*] = 1
	
    buff = ''
	ni = 0
	day2 = 2*24.*60.*60
	FOR n=0,N_ELEMENTS(files)-1 DO BEGIN
	
    	OPENR,lun,files[n],/GET_LUN, ERROR = error_status
    	IF (error_status lt 0) then begin
        	MESSAGE,/CONT,'Can not read from ' + files[n]
    	ENDIF ELSE BEGIN
            	READF,lun,buff  ;read titles
        	WHILE (NOT EOF(lun)) DO BEGIN
            	READF,lun,buff  ;read command description
            	e = STRSPLIT(STRCOMPRESS(buff),',',/EXTRACT)
				
				data.utc[0,ni] = STRCOMPRESS(e[0],/REMOVE_ALL)
				data.utc[1,ni] = STRCOMPRESS(e[1],/REMOVE_ALL)
				data.mode[ni] = LONG(e[2])
				
				s=UTC2ET(data.utc[*,ni],met)
				IF met[1] LT et[0]-day2 THEN keep[ni] = 0
				IF met[0] GT et[1]+day2 THEN keep[ni] = 0
				ni++
			ENDWHILE
		ENDELSE
		CLOSE,lun
		FREE_LUN,lun
	ENDFOR
	
	;strip off the ones that are earlier or later than time range needed
	at = WHERE(keep[*] EQ 1)
	print,'at ',at
	IF at[0] NE -1 THEN BEGIN
		mydata = {utc:data.utc[*,at],mode:data.mode[at]}
	ENDIF ELSE mydata = data
	
RETURN,status
END
