;+
; NAME:
;	SETUP
;
; PURPOSE:
;	User edited setup file which needs to be edited and run before using any of 
;   the MIMI IDL code. It reads in the leap second kernel and stores the data
;   in the common block for use by the UTC2ET and ET2UTC routines.
;   
; NOTE: 
;
; CATEGORY:
;	Setup File. 
;
; CALLING SEQUENCE:
;	SETUP
;
;
;
;                       Copyright (C) 2011
; The Johns Hopkins University Applied Physics Laboratory (JHU/APL)
;                       All rights reserved
;
; This material may be used, modified or reproduced by or for the
; U.S. Government pursuant to the license rights granted under
; the clauses at DFARS 252.227-7013/7014.
;
; CREATION:
;       01 Oct 2011, M.B. Kusterer 
;
; MODIFICATION HISTORY:
;       11 June 2012, M.B. Kusterer  Added INCA Ion/Neutral directory environmental variable
;-
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
PRO SETUP

    ;setup idl paths
    CD, CURRENT=c
    !path = c+":"+!path

    ;setup environmental variables
    p=PATH_SEP()
    
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;
    ; Start of the User edited section.
    ;
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;
    ;Change the path to reflect the user's 
	;	path to the MIMI_code_calibration directory and if the user changed
	;	the directory name.
    ;
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
	rootdir = GETENV('HOME')+p+'MIMI_code_calibration'
	
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
	;set IDL commands to control how color values are interpreted when using displays
	;with decomposed color (True Color or direct color visuals) see DECOMPOSED 
	;keyword for device command for more information
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
	device,true_color=24
	device,decomp=0

    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;set MIMICAL_NAME to path and filename of mimi calibration file 
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    SETENV,'MIMICAL_NAME='+rootdir+p+'MIMI_cal'+p+'MIMI_CALIBRATION_0011.csv'
    
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;set LEAPKERNEL_FILE to the path and filename of the SPICE Leap Second file
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    SETENV,'LEAPKERNEL_FILE='+rootdir+p+'spice_kernel'+p+'naif0009.tls'
	
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;
    ; End of the User edited section.
    ;
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    
    
    ;set INCAFLUX_DIR to directory where the MIMI INCA Flux directory set geometricfactorXefficiency_matrix is located 
    SETENV,'INCAFLUX_DIR='+rootdir+p+'INCA_cal'+p
    
    
    ;set OUTOFCAL_DIR to directory where the MIMI INCA High Voltage Out of Calibration files are located 
    SETENV,'OUTOFCAL_DIR='+rootdir+p+'INCA_outofcal_times'+p
	
    ;set NEUION_DIR to directory where the MIMI INCA Neutral/Ion Mode files  are located 
    SETENV,'NEUION_DIR='+rootdir+p+'INCA_ionneutral_times'+p
    
    ;set IDL_DIR to directory where MIMI PDS IDL code  is located 
    SETENV,'IDL_DIR='+rootdir+p+'IDL'+p
	
    
    
    ;Test MIMICAL_NAME  
    IF FILE_TEST(GETENV('MIMICAL_NAME')) NE 1 THEN BEGIN
        PRINT,'SETUP: Error opening MIMI Calibration Filename'
        RETURN
    ENDIF ELSE PRINT,'SETUP: Using MIMI Calibration File '+GETENV('MIMICAL_NAME')
    
    ;Test INCAFLUX_DIR 
    IF FILE_TEST(GETENV('INCAFLUX_DIR'),/DIRECTORY) NE 1 THEN BEGIN
        PRINT,'SETUP: Error locating MIMI INCA Flux directory '
        RETURN
    ENDIF ELSE PRINT,'SETUP: Using MIMI INCA Flux directory '+GETENV('INCAFLUX_DIR')
    
    ;Test OUTOFCAL_DIR 
    IF FILE_TEST(GETENV('OUTOFCAL_DIR'),/DIRECTORY) NE 1 THEN BEGIN
        PRINT,'SETUP: Error locating MIMI INCA Out of calibration directory '
        RETURN
    ENDIF ELSE PRINT,'SETUP: Using MIMI INCA  Out of calibration directory '+GETENV('OUTOFCAL_DIR')
	
    ;Test NEUION_DIR 
    IF FILE_TEST(GETENV('NEUION_DIR'),/DIRECTORY) NE 1 THEN BEGIN
        PRINT,'SETUP: Error locating MIMI INCA Neutral/Ion directory '
        RETURN
    ENDIF ELSE PRINT,'SETUP: Using MIMI INCA Neutral/Ion directory '+GETENV('NEUION_DIR')
    
    ;Test IDL_DIR directory  
    IF FILE_TEST(GETENV('IDL_DIR'),/DIRECTORY) NE 1 THEN BEGIN
        PRINT,'SETUP: Error locating MIMI PDS IDL code directory '
        RETURN
    ENDIF ELSE PRINT,'SETUP: Using MIMI INCA PDS IDL code directory '+GETENV('IDL_DIR')
    
    
    ;read in leap second kernel and store information in common block
    s=READ_LSK()
    IF s NE -1 THEN PRINT,'SETUP: Read in Leap Second Kernel'
RETURN
END
