; $Id: et_ascii.pro,v 1.3 2002/01/29 15:38:01 kuster Exp $
;+---------------------------------------------------------------------
; Program Name:	SPICE_ET2UTC.pro
;
; Description:  Calls CSPICE_ET2UTC now from SPICE IDL DLM

;
; Parameters:   
;  et           input array of double to ephermeris time ot be converted, 
;                       seconds from Jan 1, 2000 12:00 UTC
;  utc  		output string  UTC starttime, yyyy-doyThh:mm.sss
;       	
;                       Copyright (C) 2010
; The Johns Hopkins University Applied Physics Laboratory (JHU/APL)
;                       All rights reserved
;
; This material may be used, modified or reproduced by or for the
; U.S. Government pursuant to the license rights granted under
; the clauses at DFARS 252.227-7013/7014.
;
;
; Change History:
;
; Date		Rev	Programmer	Comments
; ----		---	----------	--------
; 6 Aug 1999    	M.B. Kusterer   Original
; 17 Jul 2001    	M.B. Kusterer  Changed library to MIMI_DECOM_SHAREDSPICELIB
; 10 Dec 2001    	M.B. Kusterer  Changed to use IDL internal routines to convert time
; 17 Nov 2002    	M.B. Kusterer   Changed to using SPICE DLM
; calls
; 
; 16 June 1005 P. C. Brandt Replaced "FOR N=0,numtodo-1 DO BEGIN" with
; "FOR N=0L,numtodo-1 DO BEGIN"
; 2 Sep 2005    	M.B. Kusterer   Replaced call to SPICE_SETUP to SPICE_SETUP2 (new meta kernel)
;	Jan 27, 2010	M.B.Kusterer	Added error handling.


;----------------------------------------------------------------------
FUNCTION SPICE_ET2UTC, et, utc

CATCH, error
IF error NE 0 THEN BEGIN
    ERROR_PRINT,status,0,ADDITIONAL='SPICE_ET2UTC'
    RETURN,-1
ENDIF

COLUMN_WIDTH = 23; width for columns in ascii file

numtodo = LONG(N_ELEMENTS(et))
utc = INIT_STRINGS(numtodo,COLUMN_WIDTH)
prec=3L      ; conver precision from et to utc

s_et = 0D
s_utc = '                                                            '
FOR N=0L,numtodo-1 DO BEGIN
    s_et = et[N]
    CSPICE_ET2UTC, s_et, "ISOD", prec, s_utc
    utc[N]=s_utc
ENDFOR

RETURN, 0
END
