; $Id: scetsclk.pro,v 1.3 2002/01/29 15:38:13 kuster Exp $
;+---------------------------------------------------------------------
; Program Name:	spice_scetsclk.pro
;
; Description:  Calls CSPICE_UTC2ET and CSPICE_SCE2S now from DLM

;               (Use to call  C code, call_scetsclk.c , which calls C++
;               routine scetsclk.cpp to call fortran SPICE routine et2utc to finally
;               convert array of [numtodo] ascii representation to et (ephemeris time ,
;               seconds from jan 1, 2000 UTC)
;               Links with C library specified by environmental variable MIMI_DECOM_SHAREDLIB. 
;               That C library must be 
;               linked with the Processor Science Record library libsr.so in C++.)
;
; Parameters:   
; Input:                                      
;   long    *sc:     Spacecraft ID (Cassini -82)
;   long    *numtodo    Number of scets to process
;   IDL_STRING    *scet:  [n] Spacecraft Event Time in UTC
; Output:
;   long    *errst: Error number corresponse to error message 
;                       in "errormeg.h" file 
;   unsigned long    [n] sclk:  Spacecraft Clock
;   unsigned char    [n] sclk_secs: Spacecraft Clock subseconds
;   double  *et:    [n] Ephemeris seconds past J2000
;   unsigned char   *part_num:   partition # default = 1
;       	
; Change History:
;
; Date		Rev	Programmer	Comments
; ----		---	----------	--------
; 6 Aug 1999    	M.B. Kusterer   Original
; 17 Jul 2001    	M.B. Kusterer  Changed library to MIMI_DECOM_SHAREDSPICELIB
; 10 Dec 2001    	M.B. Kusterer  Changed to use IDL internal routines to convert time
;       10 Jan 2002, M.B. Kusterer  Updated for new time structure
; 17 Nov 2002    	M.B. Kusterer   Changed to using SPICE DLM calls
;	Jan 27, 2010	M.B.Kusterer	Added error handling.
;----------------------------------------------------------------------
FUNCTION spice_scetsclk, scet, sclk_secs, sclk_fine, et  


CATCH, error
IF error NE 0 THEN BEGIN
    PRINT,'SPICE_SCETSCLK error'
    RETURN,-1
ENDIF

;save space for IDL variables
sc = -82L
numtodo = LONG(N_ELEMENTS(scet))
sclk_secs = ULONARR(numtodo)
sclk_fine = LONARR(numtodo)
errst = 0L
et = DBLARR(numtodo)
part_num = BYTE(1)
result = 0L
SCLKLEN = 80L
      
s_et = 0D              
s_utc = '                                                            '
s_sclk = '                                                                                '
FOR N=0l,numtodo-1 DO BEGIN
    s_utc = scet[N]
    CSPICE_UTC2ET, s_utc, s_et
    CSPICE_SCE2S, sc, s_et, s_sclk
    et[N]=s_et
    ll = STRPOS(s_sclk,'/')
    lp = STRPOS(s_sclk,'.')
    part_num  = LONG(STRMID(s_sclk,0,ll))
    sclk_secs[N] = ULONG(STRMID(s_sclk,ll+1,lp-ll))
    sclk_fine[N] = LONG(STRMID(s_sclk,lp+1))
ENDFOR

RETURN, 0
END
