; $Id: scetsclk.pro,v 1.3 2002/01/29 15:38:13 kuster Exp $
;+---------------------------------------------------------------------
; Program Name:	SPICE_UTC2ET.pro
;
; Description:  Calls CSPICE_UTC2ET from DLM

;               (Use to call  C code, call_scetsclk.c , which calls C++
;               routine scetsclk.cpp to call fortran SPICE routine et2utc to finally
;               convert array of [numtodo] ascii representation to et (ephemeris time ,
;               seconds from jan 1, 2000 UTC)
;               Links with C library specified by environmental variable MIMI_DECOM_SHAREDLIB. 
;               That C library must be 
;               linked with the Processor Science Record library libsr.so in C++.)
;
; Parameters:   
; Input:                                      
;   IDL_STRING    *scet:  [n] Spacecraft Event Time in UTC
; Output:
;   double  *et:    [n] Ephemeris seconds past J2000
;       
;                       Copyright (C) 2010
; The Johns Hopkins University Applied Physics Laboratory (JHU/APL)
;                       All rights reserved
;
; This material may be used, modified or reproduced by or for the
; U.S. Government pursuant to the license rights granted under
; the clauses at DFARS 252.227-7013/7014.	
;
;
; Change History:
;
; Date		Rev	Programmer	Comments
; ----		---	----------	--------
; 17 Nov 2002    	M.B. Kusterer   Original
; 2 Sep 2005    	M.B. Kusterer   Replaced call to SPICE_SETUP to SPICE_SETUP2 (new meta kernel)
;	Jan 27, 2010	M.B.Kusterer	Added error handling.
;----------------------------------------------------------------------
FUNCTION SPICE_UTC2ET, utc, et  


CATCH, error
IF error NE 0 THEN BEGIN
    ERROR_PRINT,status,0,ADDITIONAL='SPICE_UTC2ET '+utc+' '
    RETURN,-1
ENDIF

;save space for IDL variables
sc = -82L
numtodo = LONG(N_ELEMENTS(utc))
et = DBLARR(numtodo)
      
s_et = 0D              
s_utc = '                                                            '
FOR N=0l,numtodo-1 DO BEGIN
    s_utc = utc[N]
    CSPICE_UTC2ET, s_utc, s_et
    et[N]=s_et
ENDFOR

RETURN, 0
END
