;+
; NAME:
;	TAI2UTC
;
; PURPOSE:
;	Convert TAI to UTC string
;   
; NOTE: 
;
; CATEGORY:
;	Mathematical support. 
;
; CALLING SEQUENCE:
;	utc = TAI2UTC(tai)
;
; INPUTS:
;   tai     double array of TAI times (international atomic time)
;
; RETURNS:
;   utc     String UTC, yyyy-doyThh:mm:ss.msc (Coordinated Universal Time).
;
;
; REQUIRES:
;   Uses the leap second common block, assumes setup was run before use
;
;   The leap second file is obtained from "ftp://naif.jpl.nasa.gov/pub/naif/CASSINI/kernels/lsk/" 
;   and the user should check in January and August of each year to see if any leap seconds have 
;   been added.
;
; KEYWORD PARAMETERS:
;
;
;
;
;                       Copyright (C) 2009
; The Johns Hopkins University Applied Physics Laboratory (JHU/APL)
;                       All rights reserved
;
; This material may be used, modified or reproduced by or for the
; U.S. Government pursuant to the license rights granted under
; the clauses at DFARS 252.227-7013/7014.
;
; CREATION:
;       01 Oct 2009, M.B. Kusterer 
;
; MODIFICATION HISTORY: 
;-
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
PRO TEST_TAIU

    
    utc = '2005-365T23:38:00.000' 
    tai = UTC2TAI(utc)
    print,TAI2UTC(tai),format='(F23.2)'
    utc = '2006-001T00:00:00.000' 
    tai = UTC2TAI(utc)
    print,TAI2UTC(tai),format='(F23.2)'
    
RETURN
END

FUNCTION TAI2UTC, tai

COMMON LEAP, ls


    delta_at = GET_DELTA_AT( '', USETAI=tai)

    ;get julian seconds 0:00 1 Jan 2000 and adjust to get 12 noon
    juliansecs = tai - DOUBLE(delta_at)  
    
    
   RETURN,JSECS2UTC(juliansecs)
END
