;+
; NAME:
;	TEST_READ_MIMI
;
; PURPOSE:
;	Example routine which calls PDS_READ_MIMI to read MIMI non-image PDS data. 
;   Please take a look at the header of PDS_READ_MIMI for more information on the routine.
;
; CATEGORY:
;	Plotting Structure File. 
;
; CALLING SEQUENCE:
;   TEST_READ_MIMIIMG, data, labels, datautc, auxdata, auxlabels
;
; INPUTS:
;
; OUTPUTS:
;   labels                  String array containing data column labels [numcols]
;   data                    Double array containing data [numrows, numcols]
;	utc						String arraay containing the utc of the data [numrows]
;   auxdata           Double array containing auxiliary data [6, numcols]
;   auxlabels         String array containing auxiliary data column labels [6]
;
;
; KEYWORD PARAMETERS:
;
;
;                       Copyright (C) 2011
; The Johns Hopkins University Applied Physics Laboratory (JHU/APL)
;                       All rights reserved
;
; This material may be used, modified or reproduced by or for the
; U.S. Government pursuant to the license rights granted under
; the clauses at DFARS 252.227-7013/7014.
;
; CREATION:
;       10 Nov 2011, M.B. Kusterer 
;
; MODIFICATION HISTORY: 
;       23 Mar 2012, M.B. Kusterer Combined time definitions together to be less confusing. 
;		Added more error testing.
;       05 Jun 2012, M.B. Kusterer Changed to using version 3 files
;-
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
PRO TEST_READ_MIMI, data, labels, datautc, auxdata, auxlabels

@pds_data_hdr_h   ; include this file to get column definition constants

	;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
	;  NOTE:
	;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
	;>>(*) User Action: in this routine there are three locations the user  
	;      needs to edit variables in order to list their own selected files 
	;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
	;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


	;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
	;set up data information, just so we don't 
	;have to remember the directory names, these are the pds directory names
	;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
	lemmspds = ['LEMMS_ACCUMULATION_RATES','LEMMS_FINE_ACCUMULATION_RATES','LEMMS_PULSE_HEIGHT_ANALYSIS']
	chemspds = ['CHEMS_SCIENCE_RATES','CHEMS_ACCUMULATION_RATES','CHEMS_PULSE_HEIGHT_ANALYSIS']
	incapds = ['INCA_ACCUMULATION_RATES','INCA_PULSE_HEIGHT_ANALYSIS']
	imagepds = 'INCA_IMAGES'

	;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
	;>>(1) set up data location, yours can be just a simple topdir='/user/frank/'
	;as it is, directory would be
	;/project/cassini/ftpdata/PDS_Volumes/COMIMI_0SAT/DATA/<sensordir>/<year>/filename
	;p for path_sep is included for those who want to have platform independent code
	;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
	p=PATH_SEP()	;is "/" for unix, linux, darwin
	topdir = (!version.os EQ 'darwin') ? $
		GETENV('HOME')+p+'project'+p+'cassini'+p+'ftpdata'+p+'PDS_Volumes'+p+'COMIMI_0SAT'+p+'DATA'+p : $
		p+'project'+p+'cassini'+p+'df004'+p+'PDS_Volumes'+p+'COMIMI_0SAT'+p+'DATA'+p
		
	;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
	;>>(2) identify the files you want to list
	;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
	;sensordir = lemmspds[0]+p
	;file = [topdir+sensordir+'2010'+p+'LACC4_2010182_0003.CSV',$
	;		topdir+sensordir+'2010'+p+'LACC4_2010183_0003.CSV']
	
    ;sensordir = lemmspds[1]+p
	;file = [topdir+sensordir+'2010'+p+'LFRT4_2010182_0003.CSV',$
	;		topdir+sensordir+'2010'+p+'LFRT4_2010183_0003.CSV']
	;sensordir = lemmspds[2]+p
	;file = [topdir+sensordir+'2010'+p+'LPHA0_2010182_0003.CSV',$
	;		topdir+sensordir+'2010'+p+'LPHA0_2010183_0003.CSV']
	
	;sensordir = chemspds[0]+p
	;file = [topdir+sensordir+'2010'+p+'CSCI0_2010182_0003.CSV',$
	;		topdir+sensordir+'2010'+p+'CSCI0_2010183_0003.CSV']
	
	;sensordir = chemspds[1]+p
	;file = [topdir+sensordir+'2010'+p+'CACC0_2010182_0003.CSV',$
	;		topdir+sensordir+'2010'+p+'CACC0_2010183_0003.CSV']
	;sensordir = chemspds[2]+p
	;file = [topdir+sensordir+'2010'+p+'CPHA0_2010182_0003.CSV',$
	;		topdir+sensordir+'2010'+p+'CPHA0_2010183_0003.CSV']
	
	sensordir = incapds[0]+p
	file = [topdir+sensordir+'2010'+p+'IACC0_2010182_0003.CSV',$
			topdir+sensordir+'2010'+p+'IACC0_2010183_0003.CSV']
	
	
	;sensordir = incapds[1]+p
	;file = [topdir+sensordir+'2010'+p+'IPHA0_2010182_0003.CSV',$
	;		topdir+sensordir+'2010'+p+'IPHA0_2010183_0003.CSV']
	
	print, 'Using '+file
	
	;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
	;>>(3) set up time to match file selected
	;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
	startyear = 2010
	startdoy = 182
	starthours = 12
	startmins = 30
	startsecs = 0
	
	stopyear = 2010
	stopdoy = 183
	stophours = 4
	stopmins = 30
	stopsecs = 0
	
	;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
	;convert times to ascii UTC string to ephemeris time, 
	;et is dblarr[2], 0=starting time, 1=ending time
	;ephemeris time makes it easier to find matching times
	;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
	strtime = NUM2TIMESTR(startyear, startdoy, starthours, startmins, startsecs)
	stptime = NUM2TIMESTR(stopyear, stopdoy, stophours, stopmins, stopsecs)
	s=UTC2ET([strtime,stptime],et)
	
	;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
	;call read routine
	;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
	s = PDS_READ_MIMI(startyear, startdoy, starthours, startmins, startsecs, $
                    stopyear, stopdoy, stophours, stopmins, stopsecs, file,$
                    labels, data, datautc, auxdata, auxlabels)
		
	IF s EQ 0 THEN BEGIN
		help,labels, data, datautc, auxdata, auxlabels

		minet = data[0,DATA_ET_SECS_C]
		maxet = data[N_ELEMENTS(data[*,0])-1,DATA_ET_SECS_C]
		s=ET2UTC([minet,maxet],utc)
		print,'TEST_READ_MIMI: Files contain time range ',utc
		
		;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
		;print out some data, channel START_PULSE
		;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;	

		;locate column where the start_pulse data is
		print,labels
		icol = WHERE(STRPOS(STRLOWCASE(labels),STRLOWCASE('START_PULSE')) NE -1)
		IF icol[0] EQ -1 THEN BEGIN
			PRINT,'TEST_READ_MIMI: Failure to locate that channel in the data files'
			RETURN
		ENDIF
		
		;locate times that are within our time range
		at = WHERE(data[*,DATA_ET_SECS_C] GE et[0] AND data[*,DATA_ET_SECS_C] LE et[1])
		IF at[0] EQ -1 THEN BEGIN
			PRINT,'TEST_READ_MIMI: Failure to locate that time range '+strtime+' '+stptime+$
				' in the data files '
			RETURN
		ENDIF
		
		print,'Output:'
		IF at[0] NE -1 AND icol[0] NE -1 THEN BEGIN
			FOR n=0,n_elements(at)-1 DO BEGIN
				print,datautc[at[n]],' ',data[at[n], icol]
			ENDFOR
		ENDIF
	ENDIF ELSE BEGIN
	
	ENDELSE
	
RETURN
END

