;+
; NAME:
;	TIMESTR2NUM
;
; PURPOSE:
;	Convert from string time format to year, day of year, hours, minutes and seconds
;   
; NOTE: 
;
; CATEGORY:
;	Plotting Structure File. 
;
; CALLING SEQUENCE:
;	TIMESTR2NUM, timestr, year, doy, hours, mins, secs, msecs
;
; INPUTS:
;	strtime	String or String array of form yyyy-doyThh:mm:ss
;
; OUTPUTS:
;   year     integer 4 digit integer year
;   doy      integer day of year 1-365 or 366 on leap year
;   hours    integer hours 0-23, can be array
;   mins     integer minutes 0-59, can be array
;   secs     integer seconds 0-59, can be array
;
;   RETURNS 0 indicates that the file was found and data was returned
;           -1 indicates that either the file was not found or was unable to read or no data matched.
;
; KEYWORD PARAMETERS:
;
;                       Copyright (C) 2011
; The Johns Hopkins University Applied Physics Laboratory (JHU/APL)
;                       All rights reserved
;
; This material may be used, modified or reproduced by or for the
; U.S. Government pursuant to the license rights granted under
; the clauses at DFARS 252.227-7013/7014.
;
; CREATION:
;       01 Oct 2010, M.B. Kusterer 
;
; MODIFICATION HISTORY: 
;-
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
PRO TEST2NUM
	timestr = '2001-011T01:02:03.999'
	TIMESTR2NUM, timestr, year, doy, hours, mins, secs, msecs
	PRINT,year, doy, hours, mins, secs, msecs
RETURN
END

PRO TIMESTR2NUM, timestr, year, doy, hours, mins, secs, msecs
    
	num=N_ELEMENTS(timestr)
	year = LONARR(num)
	doy = LONARR(num)
	hours = LONARR(num)
	mins = LONARR(num)
	secs = LONARR(num)
	msecs = LONARR(num)
	
	FOR n=0,num-1 DO BEGIN
    	year[n] = LONG(STRMID(timestr[n],0,4))
    	doy[n] = LONG(STRMID(timestr[n],5,3))
    	IF STRLEN(timestr[n]) GE 11 THEN hours[n] = LONG(STRMID(timestr[n],9,2))
    	IF STRLEN(timestr[n]) GE 14 THEN mins[n] = LONG(STRMID(timestr[n],12,2))
    	IF STRLEN(timestr[n]) GE 17 THEN secs[n] = LONG(STRMID(timestr[n],15,2))
    	IF STRLEN(timestr[n]) GE 21 THEN msecs[n] = LONG(STRMID(timestr[n],18,3))
	ENDFOR
     
RETURN
END
