;+
; NAME:
;	UTC2TAI
;
; PURPOSE:
;	Convert UTC string to TAI
;   
; NOTE: 
;
; CATEGORY:
;	Plotting Structure File. 
;
; CALLING SEQUENCE:
;	tai = UTC2TAI(utc)
;
; INPUTS:
;   utc     String UTC, yyyy-doyThh:mm:ss.msc (Coordinated Universal Time).
;
; RETURNS:
;   tai     double array of TAI times (international atomic time)
;
; REQUIRES:
;   Uses the leap second common block, assumes setup was run before use
;
;   The leap second file is obtained from "ftp://naif.jpl.nasa.gov/pub/naif/CASSINI/kernels/lsk/" 
;   and the user should check in January and August of each year to see if any leap seconds have 
;   been added.
;
; KEYWORD PARAMETERS:
;
;
;
;
;                       Copyright (C) 2011
; The Johns Hopkins University Applied Physics Laboratory (JHU/APL)
;                       All rights reserved
;
; This material may be used, modified or reproduced by or for the
; U.S. Government pursuant to the license rights granted under
; the clauses at DFARS 252.227-7013/7014.
;
; CREATION:
;       01 Oct 2009, M.B. Kusterer 
;
; MODIFICATION HISTORY: 
;-
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
PRO TEST_UTAI,utc

    utc = '2005-365T23:38:00.000' 
    utc = '2006-001T00:00:00.000'
    print,UTC2TAI(utc[0]),format='(F23.2)'
    
RETURN
END

FUNCTION UTC2TAI, utc

COMMON LEAP, ls

    ;get julian seconds 0:00 1 Jan 2000 and adjust to get 12 noon
    juliansecs = UTC2JSECS(utc)  
    
    ;find delta_at (difference between TAI and UTC) for utc
    delta_at = GET_DELTA_AT( utc)
    
    ;TAI = UTC + delta_at
   RETURN,juliansecs + delta_at
END
